# -*- coding: utf-8 -*-
'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2023 Cool Dude 2k - http://idb.berlios.de/
    Copyright 2011-2023 Game Maker 2k - http://intdb.sourceforge.net/
    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: precairo.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1  - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import cairo, upcean.fonts;

try:
 import pkg_resources;
 pkgres = True;
except ImportError:
 pkgres = False;

try:
 import pkg_resources;
 pkgres = True;
except ImportError:
 pkgres = False;

fontpathocra = upcean.fonts.fontpathocra;
fontpathocraalt = upcean.fonts.fontpathocraalt;
fontpathocrb = upcean.fonts.fontpathocrb;
fontpathocrbalt = upcean.fonts.fontpathocrbalt;
fontpath = upcean.fonts.fontpath;

'''
http://stevehanov.ca/blog/index.php?id=28
'''
def snapCoords( ctx, x, y ):
 (xd, yd) = ctx.user_to_device(x, y);
 return ( round(x) + 0.5, round(y) + 0.5 );

def drawLine( ctx, x1, y1, x2, y2 ):
 point1 = snapCoords( ctx, x1, y1 );
 point2 = snapCoords( ctx, x2, y2 );
 ctx.move_to( point1[0], point1[1] );
 ctx.line_to( point2[0], point2[1] );
 ctx.set_line_width( 1.0 );
 ctx.stroke();
 return True;

def drawRectangle( ctx, x1, y1, x2, y2 ):
 point1 = snapCoords( ctx, x1, y1 );
 point2 = snapCoords( ctx, x2, y2 );
 ctx.move_to( point1[0], point1[1] );
 ctx.rectangle( point1[0], point1[1], point2[0], point2[1] )
 ctx.set_line_width( 1.0 );
 ctx.stroke();
 return True;

def drawColorRectangle( ctx, x1, y1, x2, y2, color ):
 ctx.set_source_rgb(color[0], color[1], color[2]);
 drawRectangle(ctx, x1, y1, x2, y2);
 ctx.close_path();
 return True;

def drawColorLine( ctx, x1, y1, x2, y2, width, color ):
 ctx.set_source_rgb(color[0], color[1], color[2]);
 if(width < 1): 
  width = 1;
 width -= 1;
 if(width < 1):
  drawLine(ctx, x1, y1, x2, y2);
 else:
  drawRectangle(ctx, x1, y1, x2 + width, y2);
 ctx.close_path();
 return True;

def drawText( ctx, size, x, y, text, ftype = "ocrb"  ):
 text = str(text);
 point1 = snapCoords( ctx, x, y );
 ctx.select_font_face( "Monospace" );
 ctx.set_font_size( size );
 fo = cairo.FontOptions();
 fo.set_antialias(cairo.ANTIALIAS_NONE);
 '''
 fo.set_hint_style(cairo.HINT_STYLE_NONE);
 fo.set_hint_metrics(cairo.HINT_METRICS_OFF);
 '''
 ctx.set_font_options(fo);
 ctx.move_to( point1[0], point1[1] );
 ctx.show_text( text );
 ctx.stroke();
 return True;

def drawColorText( ctx, size, x, y, text, color, ftype = "ocrb"  ):
 text = str(text);
 ctx.set_source_rgb(color[0], color[1], color[2]);
 drawText(ctx, size, x, y, text, ftype);
 return True;



# -*- coding: utf-8 -*-
'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: plessey.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import re, os, sys, types, upcean.barcodes.getsfname, upcean.support;
try:
 from io import StringIO, BytesIO;
except ImportError:
 try:
  from cStringIO import StringIO;
  from cStringIO import StringIO as BytesIO;
 except ImportError:
  from StringIO import StringIO;
  from StringIO import StringIO as BytesIO;
pilsupport = upcean.support.check_for_pil();
cairosupport = upcean.support.check_for_cairo();
from upcean.barcodes.predraw import *;
if(pilsupport):
 import upcean.barcodes.prepil;
if(cairosupport):
 import upcean.barcodes.precairo;

def create_plessey_barcode(upc,outfile="./plessey.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 upc = str(upc);
 hidesn = hideinfo[0];
 hidecd = hideinfo[1];
 hidetext = hideinfo[2];
 imageoutlib = imageoutlib.lower();
 if(not pilsupport and imageoutlib=="pillow"):
  imageoutlib = "cairo";
 if(not cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
  imageoutlib = "pillow";
 if(not cairosupport and imageoutlib=="cairosvg"):
  imageoutlib = "pillow";
 if(imageoutlib!="pillow" and imageoutlib!="cairo" and imageoutlib!="cairosvg"):
  imageoutlib = "pillow";
 if(not pilsupport and not cairosupport):
  return False;
 if(outfile is None):
  if(imageoutlib=="cairosvg"):
   oldoutfile = None;
   outfile = None;
   outfileext = "SVG";
  else:
   oldoutfile = None;
   outfile = None;
   outfileext = None;
 else:
  oldoutfile = upcean.barcodes.getsfname.get_save_filename(outfile, imageoutlib);
  if(isinstance(oldoutfile, tuple) or isinstance(oldoutfile, list)):
   del(outfile);
   outfile = oldoutfile[0];
   outfileext = oldoutfile[1];
   if(cairosupport and imageoutlib=="cairo" and outfileext=="SVG"):
    imageoutlib = "cairosvg";
   if(cairosupport and imageoutlib=="cairosvg" and outfileext!="SVG"):
    imageoutlib = "cairo";
 if(len(upc) < 1): 
  return False;
 if(barwidth < 1): 
  barwidth = 1;
 if(not re.findall("([0-9a-fA-F]+)", upc)):
  return False;
 if(not re.findall("^([0-9]*[\.]?[0-9])", str(resize)) or int(resize) < 1):
  resize = 1;
 if(pilsupport and imageoutlib=="pillow"):
  try:
   pil_ver = Image.PILLOW_VERSION;
   pil_ver = pil_ver.split(".");
   pil_ver = [int(x) for x in pil_ver];
   pil_is_pillow = True;
  except AttributeError:
   try:
    pil_ver = Image.VERSION;
    pil_is_pillow = False;
   except AttributeError:
    pil_ver = Image.__version__;
    pil_is_pillow = True;
   except NameError:
    pil_ver = Image.__version__;
    pil_is_pillow = True;
   pil_ver = pil_ver.split(".");
   pil_ver = [int(x) for x in pil_ver];
  except NameError:
   try:
    pil_ver = Image.VERSION;
    pil_is_pillow = False;
   except AttributeError:
    pil_ver = Image.__version__;
    pil_is_pillow = True;
   except NameError:
    pil_ver = Image.__version__;
    pil_is_pillow = True;
   pil_ver = pil_ver.split(".");
   pil_ver = [int(x) for x in pil_ver];
  pil_addon_fix = 0;
  cairo_addon_fix = 0;
  pil_prevercheck = [str(x) for x in pil_ver];
  pil_vercheck = int(pil_prevercheck[0]+pil_prevercheck[1]+pil_prevercheck[2]);
  if(pil_is_pillow and pil_vercheck>=210 and pil_vercheck<220):
   pil_addon_fix = int(resize) * 2;
   cairo_addon_fix = 0;
 elif(pilsupport and imageoutlib=="pillow"):
  pil_addon_fix = 0;
  cairo_addon_fix = 0;
 elif(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
  pil_addon_fix = 0;
  cairo_addon_fix = (8 * (int(resize) ) );
 else:
  pil_addon_fix = 0;
  cairo_addon_fix = 0;
 upc = upc.upper();
 upc_matches = list(upc);
 upc_size_add = ((len(upc_matches) * 16) + (len(upc_matches) + 1)) * barwidth;
 if(len(upc_matches)<=0):
  return False;
 if(pilsupport and imageoutlib=="pillow"):
  upc_preimg = Image.new("RGB", ((48 * barwidth) + upc_size_add, barheight[1] + 9));
  upc_img = ImageDraw.Draw(upc_preimg);
  upc_img.rectangle([(0, 0), ((48 * barwidth) + upc_size_add, barheight[1] + 9)], fill=barcolor[2]);
 if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
  if(outfileext=="SVG"):
   upc_preimg = cairo.SVGSurface(None, (48 * barwidth) + upc_size_add, barheight[1] + 9);
  else:
   upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, (48 * barwidth) + upc_size_add, barheight[1] + 9);
  upc_img = cairo.Context (upc_preimg);
  upc_img.set_antialias(cairo.ANTIALIAS_NONE);
  upc_img.rectangle(0, 0, (48 * barwidth) + upc_size_add, barheight[1] + 9);
  upc_img.set_source_rgb(barcolor[2][0], barcolor[2][1], barcolor[2][2]);
  upc_img.fill();
 upc_array = { 'upc': upc, 'code': [ ] };
 LineSize = barheight[0];
 if(hidetext):
  LineSize = barheight[1];
 start_barcolor = [0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0];
 LineStart = 0;
 BarNum = 0;
 start_bc_num_end = len(start_barcolor);
 while(BarNum < start_bc_num_end):
  if(start_barcolor[BarNum]==1):
   drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[0], imageoutlib);
  if(start_barcolor[BarNum]==0):
   drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib);
  LineStart += barwidth;
  BarNum += 1;
 NumZero = 0; 
 while (NumZero < len(upc_matches)):
  left_barcolor = [1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="0"):
   left_barcolor = [1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="1"):
   left_barcolor = [1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="2"):
   left_barcolor = [1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="3"):
   left_barcolor = [1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="4"):
   left_barcolor = [1, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="5"):
   left_barcolor = [1, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="6"):
   left_barcolor = [1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="7"):
   left_barcolor = [1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0];
  if(upc_matches[NumZero]=="8"):
   left_barcolor = [1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0];
  if(upc_matches[NumZero]=="9"):
   left_barcolor = [1, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0];
  if(upc_matches[NumZero]=="A"):
   left_barcolor = [1, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0];
  if(upc_matches[NumZero]=="B"):
   left_barcolor = [1, 1, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0];
  if(upc_matches[NumZero]=="C"):
   left_barcolor = [1, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0];
  if(upc_matches[NumZero]=="D"):
   left_barcolor = [1, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0];
  if(upc_matches[NumZero]=="E"):
   left_barcolor = [1, 0, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0];
  if(upc_matches[NumZero]=="F"):
   left_barcolor = [1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0];
  InnerUPCNum = 0;
  while (InnerUPCNum < len(left_barcolor)):
   if(left_barcolor[InnerUPCNum]==1):
    drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[0], imageoutlib); 
    LineStart += barwidth;
    BarNum += 1;
   if(left_barcolor[InnerUPCNum]==0):
    drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib); 
    LineStart += barwidth;
    BarNum += 1;
   InnerUPCNum += 1;
  drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib); 
  LineStart += barwidth; 
  BarNum += 1;
  NumZero += 1;
 end_barcolor = [1, 1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
 end_bc_num = 0;
 end_bc_num_end = len(end_barcolor);
 while(end_bc_num < end_bc_num_end):
  if(end_barcolor[end_bc_num]==1):
   drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[0], imageoutlib);
  if(end_barcolor[end_bc_num]==0):
   drawColorLine(upc_img, LineStart, 4, LineStart, LineSize, barwidth, barcolor[2], imageoutlib);
  end_bc_num += 1;
  LineStart += barwidth;
  BarNum += 1;
 if(pilsupport and imageoutlib=="pillow"):
  new_upc_img = upc_preimg.resize((((48 * barwidth) + upc_size_add) * int(resize), (barheight[1] + 9) * int(resize)), Image.NEAREST); # use nearest neighbour
  del(upc_img);
  del(upc_preimg);
  upc_img = ImageDraw.Draw(new_upc_img);
 if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
  upc_imgpat = cairo.SurfacePattern(upc_preimg);
  scaler = cairo.Matrix();
  scaler.scale(1/int(resize),1/int(resize));
  upc_imgpat.set_matrix(scaler);
  upc_imgpat.set_filter(cairo.FILTER_NEAREST);
  if(outfileext=="SVG"):
   if(outfile is None):
    svgoutfile = None;
   else:
    if(sys.version[0]=="2"):
     svgoutfile = StringIO();
    if(sys.version[0]>="3"):
     svgoutfile = BytesIO();
   new_upc_preimg = cairo.SVGSurface(svgoutfile, ((48 * barwidth) + upc_size_add) * int(resize), (barheight[1] + 9) * int(resize));
  else:
   new_upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, ((48 * barwidth) + upc_size_add) * int(resize), (barheight[1] + 9) * int(resize));
  new_upc_img = cairo.Context(new_upc_preimg);
  new_upc_img.set_source(upc_imgpat);
  new_upc_img.paint();
  upc_img = new_upc_img;
 if(not hidetext):
  NumTxtZero = 0; 
  LineTxtStart = 30 * int(resize);
  while (NumTxtZero < len(upc_matches)):
   drawColorText(upc_img, 10 * int(resize), (LineTxtStart + (int(resize) - 1)) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), upc_matches[NumTxtZero], barcolor[1], "ocrb", imageoutlib);
   LineTxtStart += 16 * int(resize);
   NumTxtZero += 1;
 del(upc_img);
 if(oldoutfile is None or isinstance(oldoutfile, bool)):
  if(pilsupport and imageoutlib=="pillow"):
   return new_upc_img;
  if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   return new_upc_preimg;
 if(sys.version[0]=="2"):
  if(outfile=="-" or outfile=="" or outfile==" " or outfile is None):
   stdoutfile = StringIO();
   try:
    if(pilsupport and imageoutlib=="pillow"):
     if(outfileext=="BYTES"):
      stdoutfile.write(new_upc_img.tobytes());
      stdoutfile.seek(0);
      return stdoutfile;
     else:
      new_upc_img.save(stdoutfile, outfileext);
      stdoutfile.seek(0);
      return stdoutfile;
    if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
     if(outfileext=="BYTES"):
      stdoutfile.write(new_upc_preimg.get_data().tobytes());
      stdoutfile.seek(0);
      return stdoutfile;
     elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
      new_upc_preimg.flush();
      new_upc_preimg.finish(); 
      svgoutfile.seek(0);
      svgouttext = svgoutfile.read();
      stdoutfile.write(svgouttext);
      svgoutfile.close();
      stdoutfile.seek(0);
      return stdoutfile;
     else:
      new_upc_preimg.write_to_png(stdoutfile);
      stdoutfile.seek(0);
      return stdoutfile;
   except:
    return False;
 if(sys.version[0]>="3"):
  stdoutfile = BytesIO();
  if(outfile=="-" or outfile=="" or outfile==" " or outfile is None):
   try:
    if(pilsupport and imageoutlib=="pillow"):
     if(outfileext=="BYTES"):
      stdoutfile.write(new_upc_img.tobytes());
      stdoutfile.seek(0);
      return stdoutfile;
     else:
      new_upc_img.save(stdoutfile, outfileext);
      stdoutfile.seek(0);
      return stdoutfile;
    if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
     if(outfileext=="BYTES"):
      stdoutfile.write(new_upc_preimg.get_data().tobytes());
      stdoutfile.seek(0);
      return stdoutfile;
     elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
      new_upc_preimg.flush();
      new_upc_preimg.finish(); 
      svgoutfile.seek(0);
      svgouttext = svgoutfile.read();
      stdoutfile.write(svgouttext);
      svgoutfile.close();
      stdoutfile.seek(0);
      return stdoutfile;
     else:
      new_upc_preimg.write_to_png(stdoutfile);
      stdoutfile.seek(0);
      return stdoutfile;
   except:
    return False;
 if(outfile!="-" and outfile!="" and outfile!=" "):
  try:
   if(pilsupport and imageoutlib=="pillow"):
    if(outfileext=="BYTES"):
     with open(outfile, 'wb+') as f:
      f.write(new_upc_img.tobytes());
    else:
     new_upc_img.save(outfile, outfileext);
   if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
    if(outfileext=="BYTES"):
     with open(outfile, 'wb+') as f:
      f.write(new_upc_preimg.get_data().tobytes());
     return True;
    elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
     new_upc_preimg.flush();
     new_upc_preimg.finish(); 
     svgoutfile.seek(0);
     svgouttext = svgoutfile.read();
     with open(outfile, 'wb+') as f:
      f.write(svgouttext);
     return True;
    else:
     new_upc_preimg.write_to_png(outfile);
     return True;
  except:
   return False;
 return True;

def draw_plessey_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return create_plessey_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);



# -*- coding: utf-8 -*-
'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: convert.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import re, upcean.validate;

def make_upca_barcode(numbersystem, manufacturer, product):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 product = str(product);
 if(len(numbersystem)<1 or len(manufacturer)<5 or len(product)<5):
  return False;
 if(len(numbersystem)>1):
  fix_matches = re.findall("^(\d{1})", numbersystem);
  numbersystem = fix_matches[0];
 if(len(manufacturer)>5):
  fix_matches = re.findall("^(\d{5})", manufacturer);
  manufacturer = fix_matches[0];
 if(len(product)>5):
  fix_matches = re.findall("^(\d{5})", product);
  product = fix_matches[0];
 upc = numbersystem+manufacturer+product;
 upc = upc+str(upcean.validate.validate_upca_checksum(upc, True));
 return upc;

def make_ean13_barcode(numbersystem, manufacturer, product):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 product = str(product);
 if(len(numbersystem)<2 or len(manufacturer)<5 or len(product)<5):
  return False;
 if(len(numbersystem)>2):
  fix_matches = re.findall("^(\d{2})", numbersystem);
  numbersystem = fix_matches[0];
 if(len(manufacturer)>5):
  fix_matches = re.findall("^(\d{5})", manufacturer);
  manufacturer = fix_matches[0];
 if(len(product)>5):
  fix_matches = re.findall("^(\d{5})", product);
  product = fix_matches[0];
 upc = numbersystem+manufacturer+product;
 upc = upc+str(upcean.validate.validate_ean13_checksum(upc, True));
 return upc;

def make_itf14_barcode(numbersystem, manufacturer, product):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 product = str(product);
 if(len(numbersystem)<3 or len(manufacturer)<5 or len(product)<5):
  return False;
 if(len(numbersystem)>3):
  fix_matches = re.findall("^(\d{3})", numbersystem);
  numbersystem = fix_matches[0];
 if(len(manufacturer)>5):
  fix_matches = re.findall("^(\d{5})", manufacturer);
  manufacturer = fix_matches[0];
 if(len(product)>5):
  fix_matches = re.findall("^(\d{5})", product);
  product = fix_matches[0];
 upc = numbersystem+manufacturer+product;
 upc = upc+str(upcean.validate.validate_itf14_checksum(upc, True));
 return upc;

def make_ean8_barcode(numbersystem, manufacturer, product):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 product = str(product);
 if(len(numbersystem)<1 or len(manufacturer)<3 or len(product)<3):
  return False;
 if(len(numbersystem)>1):
  fix_matches = re.findall("^(\d{1})", numbersystem);
  numbersystem = fix_matches[0];
 if(len(manufacturer)>3):
  fix_matches = re.findall("^(\d{3})", manufacturer);
  manufacturer = fix_matches[0];
 if(len(product)>3):
  fix_matches = re.findall("^(\d{3})", product);
  product = fix_matches[0];
 upc = numbersystem+manufacturer+product;
 upc = upc+str(upcean.validate.validate_ean8_checksum(upc, True));
 return upc;

def make_upce_barcode(numbersystem, manufacturer, product):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 product = str(product);
 if(len(numbersystem)<1 or len(manufacturer)<3 or len(product)<3):
  return False;
 if(len(numbersystem)>1):
  fix_matches = re.findall("^(\d{1})", numbersystem);
  numbersystem = fix_matches[0];
 if(len(manufacturer)>3):
  fix_matches = re.findall("^(\d{3})", manufacturer);
  manufacturer = fix_matches[0];
 if(len(product)>3):
  fix_matches = re.findall("^(\d{3})", product);
  product = fix_matches[0];
 upc = numbersystem+manufacturer+product;
 upc = upc+str(upcean.validate.validate_upce_checksum(upc, True));
 return upc;

def convert_barcode_from_upce_to_upca(upc):
 upc = str(upc);
 if(len(upc)==7):
  upc = upc+str(upcean.validate.validate_upce_checksum(upc,True));
 if(len(upc)>8 or len(upc)<8):
  return False;
 if(not re.findall("^(0|1)", upc)):
  return False;
 if(not upcean.validate.validate_upce_checksum(upc)):
  return False;
 if(re.findall("(0|1)(\d{5})([0-3])(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{1})(\d{1})(\d{1})(\d{1})(\d{1})(\d{1})(\d{1})", upc);
  upc_matches = upc_matches[0];
  if(int(upc_matches[6])==0):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[6]+"0000"+upc_matches[3]+upc_matches[4]+upc_matches[5]+upc_matches[7];
  if(int(upc_matches[6])==1):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[6]+"0000"+upc_matches[3]+upc_matches[4]+upc_matches[5]+upc_matches[7];
  if(int(upc_matches[6])==2):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[6]+"0000"+upc_matches[3]+upc_matches[4]+upc_matches[5]+upc_matches[7];
  if(int(upc_matches[6])==3):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[3]+"00000"+upc_matches[4]+upc_matches[5]+upc_matches[7]; 
 if(re.findall("(0|1)(\d{5})([4-9])(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{1})(\d{1})(\d{1})(\d{1})(\d{1})(\d{1})(\d{1})", upc);
  upc_matches = upc_matches[0];
  if(int(upc_matches[6])==4):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[3]+upc_matches[4]+"00000"+upc_matches[5]+upc_matches[7];
  if(int(upc_matches[6])==5):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[3]+upc_matches[4]+upc_matches[5]+"0000"+upc_matches[6]+upc_matches[7];
  if(int(upc_matches[6])==6):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[3]+upc_matches[4]+upc_matches[5]+"0000"+upc_matches[6]+upc_matches[7];
  if(int(upc_matches[6])==7):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[3]+upc_matches[4]+upc_matches[5]+"0000"+upc_matches[6]+upc_matches[7];
  if(int(upc_matches[6])==8):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[3]+upc_matches[4]+upc_matches[5]+"0000"+upc_matches[6]+upc_matches[7];
  if(int(upc_matches[6])==9):
   upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+upc_matches[3]+upc_matches[4]+upc_matches[5]+"0000"+upc_matches[6]+upc_matches[7];
 return upce;

def convert_barcode_from_upca_to_ean13(upc):
 upc = str(upc);
 if(len(upc)==11):
  upc = upc+str(upcean.validate.validate_upca_checksum(upc,True));
 if(len(upc)>13 or len(upc)<12):
  return False;
 if(not upcean.validate.validate_upca_checksum(upc)):
  return False;
 if(len(upc)==12):
  ean13 = "0"+upc;
 if(len(upc)==13):
  ean13 = upc;
 return ean13;
def convert_barcode_from_ean13_to_itf14(upc):
 upc = str(upc);
 if(len(upc)==11):
  upc = upc+str(upcean.validate.validate_upca_checksum(upc,True));
 if(len(upc)==12):
  upc = "0"+upc;
 if(len(upc)>14 or len(upc)<13):
  return False;
 if(not upcean.validate.validate_ean13_checksum(upc)):
  return False;
 if(len(upc)==13):
  itf14 = "0"+upc;
 if(len(upc)==14):
  itf14 = upc;
 return itf14;

def convert_barcode_from_upce_to_ean13(upc):
 upc = str(upc);
 return convert_barcode_from_upca_to_ean13(convert_barcode_from_upce_to_upca(upc));

def convert_barcode_from_upce_to_itf14(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_itf14(convert_barcode_from_upce_to_ean13(upc));

def convert_barcode_from_upca_to_itf14(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_itf14(convert_barcode_from_upca_to_ean13(upc));

def convert_barcode_from_ean13_to_upca(upc):
 upc = str(upc);
 if(len(upc)==12):
  upc = "0"+upc;
 if(len(upc)>13 or len(upc)<13):
  return False;
 if(not upcean.validate.validate_ean13_checksum(upc)):
  return False;
 if(not re.findall("^0(\d{12})", upc)):
  return False;
 if(re.findall("^0(\d{12})", upc)):
  upc_matches = re.findall("^0(\d{12})", upc);
  upca = upc_matches[0];
 return upca;

def convert_barcode_from_itf14_to_ean13(upc):
 upc = str(upc);
 if(len(upc)==13):
  upc = "0"+upc;
 if(len(upc)>14 or len(upc)<14): 
  return False;
 if(not upcean.validate.validate_itf14_checksum(upc)):
  return False;
 if(not re.findall("^(\d{1})(\d{12})(\d{1})", upc)):
  return False;
 if(re.findall("^(\d{1})(\d{12})(\d{1})", upc)):
  upc_matches = re.findall("^(\d{1})(\d{12})(\d{1})", upc);
  upc_matches = upc_matches[0];
  ean13 = upc_matches[1]+str(upcean.validate.validate_ean13_checksum(upc_matches[1], True));
 return ean13;

def convert_barcode_from_upca_to_upce(upc):
 upc = str(upc);
 if(len(upc)==11):
  upc = upc+str(upcean.validate.validate_upca_checksum(upc,True));
 if(len(upc)>12 or len(upc)<12):
  return False;
 if(not upcean.validate.validate_upca_checksum(upc)):
  return False;
 if(not re.findall("(0|1)(\d{11})", upc)):
  return False;
 upce = None;
 if(re.findall("(0|1)(\d{2})00000(\d{3})(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{2})00000(\d{3})(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+"0";
  upce = upce+upc_matches[3]; 
  return upce;
 if(re.findall("(0|1)(\d{2})10000(\d{3})(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{2})10000(\d{3})(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+"1";
  upce = upce+upc_matches[3]; 
  return upce;
 if(re.findall("(0|1)(\d{2})20000(\d{3})(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{2})20000(\d{3})(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+"2";
  upce = upce+upc_matches[3]; 
  return upce;
 if(re.findall("(0|1)(\d{3})00000(\d{2})(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{3})00000(\d{2})(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+"3";
  upce = upce+upc_matches[3]; 
  return upce;
 if(re.findall("(0|1)(\d{4})00000(\d{1})(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{4})00000(\d{1})(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+upc_matches[2]+"4";
  upce = upce+upc_matches[3]; 
  return upce;
 if(re.findall("(0|1)(\d{5})00005(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{5})00005(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+"5";
  upce = upce+upc_matches[2]; 
  return upce;
 if(re.findall("(0|1)(\d{5})00006(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{5})00006(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+"6";
  upce = upce+upc_matches[2]; 
  return upce;
 if(re.findall("(0|1)(\d{5})00007(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{5})00007(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+"7";
  upce = upce+upc_matches[2]; 
  return upce;
 if(re.findall("(0|1)(\d{5})00008(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{5})00008(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+"8";
  upce = upce+upc_matches[2]; 
  return upce;
 if(re.findall("(0|1)(\d{5})00009(\d{1})", upc)):
  upc_matches = re.findall("(0|1)(\d{5})00009(\d{1})", upc);
  upc_matches = upc_matches[0];
  upce = upc_matches[0]+upc_matches[1]+"9";
  upce = upce+upc_matches[2]; 
  return upce;
 if(upce is None):
  return False;
 return upce;

def convert_barcode_from_ean13_to_upce(upc):
 upc = str(upc);
 return convert_barcode_from_upca_to_upce(convert_barcode_from_ean13_to_upca(upc));

def convert_barcode_from_itf14_to_upca(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_upca(convert_barcode_from_itf14_to_ean13(upc));

def convert_barcode_from_itf14_to_upce(upc):
 upc = str(upc);
 return convert_barcode_from_upca_to_upce(convert_barcode_from_itf14_to_upca(upc));

'''
// Changing a EAN-8 code to UPC-A and EAN-13 based on whats used at: 
// Source: http://www.upcdatabase.com/
'''
def convert_barcode_from_ean8_to_upca(upc):
 upc = str(upc);
 if(len(upc)==7):
  upc = upc+str(upcean.validate.validate_ean8_checksum(upc,True));
 if(len(upc)>8 or len(upc)<8):
  return False;
 if(not upcean.validate.validate_ean8_checksum(upc)):
  return False;
 upca = "0000"+upc; 
 return upca;

def convert_barcode_from_ean8_to_ean13(upc):
 upc = str(upc);
 return convert_barcode_from_upca_to_ean13(convert_barcode_from_ean8_to_upca(upc));

def convert_barcode_from_ean8_to_itf14(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_itf14(convert_barcode_from_ean8_to_ean13(upc));

def convert_barcode_from_upca_to_ean8(upc):
 upc = str(upc);
 if(len(upc)==11):
  upc = upc+str(upcean.validate.validate_upca_checksum(upc,True));
 if(len(upc)>12 or len(upc)<12):
  return False;
 if(not upcean.validate.validate_upca_checksum(upc)):
  return False;
 if(not re.findall("^0000(\d{8})", upc)):
  return False;
 if(re.findall("^0000(\d{8})", upc)):
  upc_matches = re.findall("^0000(\d{8})", upc);
  ean8 = upc_matches[0];
 return ean8;

def convert_barcode_from_ean13_to_ean8(upc):
 upc = str(upc);
 return convert_barcode_from_upca_to_ean8(convert_barcode_from_ean13_to_upca(upc));

def convert_barcode_from_itf14_to_ean8(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_ean8(convert_barcode_from_itf14_to_ean13(upc));

'''
// ISSN (International Standard Serial Number)
// Source: http://en.wikipedia.org/wiki/International_Standard_Serial_Number
'''
def convert_barcode_from_issn8_to_issn13(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 upc = upc.replace("X", "");
 if(not upcean.validate.validate_issn8_checksum(upc)): 
  return False;
 if(len(upc)>7): 
  fix_matches = re.findall("^(\d{7})", upc); 
  upc = fix_matches[0];
 issn13 = "977"+upc+"00"+str(upcean.validate.validate_ean13_checksum("977"+upc+"00",True)); 
 return issn13;
def convert_barcode_from_issn13_to_issn8(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 upc = upc.replace("X", "");
 if(not upcean.validate.validate_ean13_checksum(upc)): 
  return False;
 if(not re.findall("/^977(\d{7})/", upc)):
  return False;
 if(re.findall("^977(\d{7})", upc)):
  upc_matches = re.findall("^977(\d{7})", upc);
  issn8 = upc_matches[1]+upcean.validate.validate_issn8_checksum(upc_matches[1],True);
 return issn8;
def convert_barcode_from_issn8_to_ean13(upc):
 upc = str(upc);
 return convert_barcode_from_issn8_to_issn13(upc);
def convert_barcode_from_ean13_to_issn8(upc):
 upc = str(upc);
 return convert_barcode_from_issn13_to_issn8(upc);
def convert_barcode_from_issn8_to_itf14(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_itf14(convert_barcode_from_issn8_to_issn13(upc));
def convert_barcode_from_itf14_to_issn8(upc):
 upc = str(upc);
 return convert_barcode_from_itf14_to_ean13(convert_barcode_from_issn13_to_issn8(upc));
def print_issn8_barcode(upc):
 upc = str(upc);
 if(len(upc)>8): 
  fix_matches = re.findall("^(\d{8})", upc); 
  upc = fix_matches[1];
 if(len(upc)>8 or len(upc)<8): 
  return False;
 if(not re.findall("^(\d{4})(\d{4})", upc)):
  return False;
 issn_matches = re.findall("^(\d{4})(\d{4})", upc);
 issn_matches = issn_matches[0];
 issn8 = issn_matches[0]+"-"+issn_matches[1];
 return issn8;
def print_issn13_barcode(upc):
 upc = str(upc);
 if(len(upc)>13): 
  fix_matches = re.findall("^(\d{13})", upc); 
  upc = fix_matches[1];
 if(len(upc)>13 or len(upc)<13): 
  return False;
 if(not re.findall("^(\d{3})(\d{4})(\d{4})(\d{2})", upc)):
  return False;
 issn_matches = re.findall("^(\d{3})(\d{4})(\d{4})(\d{2})", upc);
 issn_matches = issn_matches[0];
 issn13 = issn_matches[0]+"-"+issn_matches[1]+"-"+issn_matches[2]+"-"+issn_matches[3];
 return issn13;
def print_convert_barcode_from_issn8_to_issn13(upc):
 upc = str(upc);
 issn13 = print_issn13_barcode(convert_barcode_from_issn8_to_issn13(upc));
 return issn13;
def print_convert_barcode_from_issn13_to_issn8(upc):
 upc = str(upc);
 issn8 = print_issn8_barcode(convert_barcode_from_issn13_to_issn8(upc));
 return issn8;

'''
// ISBN (International Standard Book Number)
// Source: http://en.wikipedia.org/wiki/ISBN
'''
def convert_barcode_from_isbn10_to_isbn13(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 if(not upcean.validate.validate_isbn10_checksum(upc)):
  return False;
 if(len(upc)>9):
  fix_matches = re.findall("^(\d{9})", upc);
  upc = fix_matches[0];
  isbn13 = "978"+upc+str(upcean.validate.validate_ean13_checksum("978"+upc,True)); 
 return isbn13;
def convert_barcode_from_isbn13_to_isbn10(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 if(not upcean.validate.validate_ean13_checksum(upc)):
  return False;
 if(not re.findall("^978(\d{9})", upc)):
  return False;
 if(re.findall("^978(\d{9})", upc)):
  upc_matches = re.findall("^978(\d{9})", upc);
  isbn10 = upc_matches[0]+str(upcean.validate.validate_isbn10_checksum(upc_matches[0],True));
 return isbn10;
def convert_barcode_from_isbn10_to_ean13(upc):
 upc = str(upc);
 return convert_barcode_from_isbn10_to_isbn13(upc);
def convert_barcode_from_ean13_to_isbn10(upc):
 upc = str(upc);
 return convert_barcode_from_isbn13_to_isbn10(upc);
def convert_barcode_from_isbn10_to_itf14(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_itf14(convert_barcode_from_isbn10_to_isbn13(upc));
def convert_barcode_from_itf14_to_isbn10(upc):
 upc = str(upc);
 return convert_barcode_from_itf14_to_ean13(convert_barcode_from_isbn13_to_isbn10(upc));
def print_isbn10_barcode(upc):
 upc = str(upc);
 if(len(upc)>10):
  fix_matches = re.findall("^(\d{9})(\d{1}|X{1})", upc); 
  fix_matches = fix_matches[0]
  upc = fix_matches[0]+fix_matches[1];
 if(len(upc)>10 or len(upc)<10):
  return False;
 if(not re.findall("^(\d{1})(\d{3})(\d{5})(\d{1}|X{1})", upc)):
  return False;
 isbn_matches = re.findall("^(\d{1})(\d{3})(\d{5})(\d{1}|X{1})", upc);
 isbn_matches = isbn_matches[0];
 isbn10 = isbn_matches[0]+"-"+isbn_matches[1]+"-"+isbn_matches[2]+"-"+isbn_matches[3];
 return isbn10;
def print_isbn13_barcode(upc):
 upc = str(upc);
 if(len(upc)>13):
  fix_matches = re.findall("^(\d{13})", upc); 
  upc = fix_matches[1];
 if(len(upc)>13 or len(upc)<13):
  return False;
 if(not re.findall("^(\d{3})(\d{1})(\d{3})(\d{5})(\d{1})", upc)):
  return False;
 isbn_matches = re.findall("^(\d{3})(\d{1})(\d{3})(\d{5})(\d{1})", upc);
 isbn_matches = isbn_matches[0];
 isbn13 = isbn_matches[0]+"-"+isbn_matches[1]+"-"+isbn_matches[2]+"-"+isbn_matches[3]+"-"+isbn_matches[4];
 return isbn13;
def print_convert_barcode_from_isbn10_to_isbn13(upc):
 upc = str(upc);
 isbn13 = print_isbn13_barcode(convert_barcode_from_isbn10_to_isbn13(upc));
 return isbn13;
def print_convert_barcode_from_isbn13_to_isbn10(upc):
 upc = str(upc);
 isbn10 = print_isbn10_barcode(convert_barcode_from_isbn13_to_isbn10(upc));
 return isbn10;

'''
// ISMN (International Standard Music Number)
// Source: http://en.wikipedia.org/wiki/International_Standard_Music_Number
// Source: http://www.ismn-international.org/whatis.html
// Source: http://www.ismn-international.org/manual_1998/chapter2.html
'''
def convert_barcode_from_ismn10_to_ismn13(upc):
 upc = str(upc);
 upc = upc.replace("M", "");
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 if(not upcean.validate.validate_ismn10_checksum(upc)):
  return False;
 if(len(upc)>8):
  fix_matches = re.findall("^(\d{8})", upc); 
  upc = fix_matches[0];
 ismn13 = "9790"+upc+str(upcean.validate.validate_ean13_checksum("9790"+upc,True)); 
 return ismn13;
def convert_barcode_from_ismn13_to_ismn10(upc):
 upc = str(upc);
 upc = upc.replace("M", "");
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 if(not upcean.validate.validate_ean13_checksum(upc)):
  return False;
 if(not re.findall("^9790(\d{8})", upc)):
  return False;
 if(re.findall("^9790(\d{8})", upc)):
  upc_matches = re.findall("^9790(\d{8})", upc);
  ismn10 = upc_matches[0]+str(upcean.validate.validate_ismn10_checksum(upc_matches[0],True));
 return ismn10;
def convert_barcode_from_ismn10_to_ean13(upc):
 upc = str(upc);
 return convert_barcode_from_ismn10_to_ismn13(upc);
def convert_barcode_from_ean13_to_ismn10(upc):
 upc = str(upc);
 return convert_barcode_from_ismn13_to_ismn10(upc);
def convert_barcode_from_ismn10_to_itf14(upc):
 upc = str(upc);
 return convert_barcode_from_ean13_to_itf14(convert_barcode_from_ismn10_to_ismn13(upc));
def convert_barcode_from_itf14_to_ismn10(upc):
 upc = str(upc);
 return convert_barcode_from_itf14_to_ean13(convert_barcode_from_ismn13_to_ismn10(upc));
def print_ismn10_barcode(upc):
 upc = str(upc);
 upc = upc.replace("M", "");
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 if(len(upc)>9):
  fix_matches = re.findall("^(\d{9})", upc); 
  upc = fix_matches[0];
 if(len(upc)>9 or len(upc)<9):
  return False;
 if(not re.findall("^(\d{4})(\d{4})(\d{1})", upc)):
  return False;
 ismn_matches = re.findall("^(\d{4})(\d{4})(\d{1})", upc);
 ismn_matches = ismn_matches[0];
 ismn10 = "M-"+ismn_matches[0]+"-"+ismn_matches[1]+"-"+ismn_matches[2];
 return ismn10;
def print_ismn13_barcode(upc):
 upc = str(upc);
 if(len(upc)>13):
  fix_matches = re.findall("^(\d{13})", upc); 
  upc = fix_matches[0];
 if(len(upc)>13 or len(upc)<13):
  return False;
 if(not re.findall("^(\d{3})(\d{1})(\d{4})(\d{4})(\d{1})", upc)):
  return False;
 ismn_matches = re.findall("^(\d{3})(\d{1})(\d{4})(\d{4})(\d{1})", upc);
 ismn_matches = ismn_matches[0];
 ismn13 = ismn_matches[0]+"-"+ismn_matches[1]+"-"+ismn_matches[2]+"-"+ismn_matches[3]+"-"+ismn_matches[4];
 return ismn13;
def print_convert_barcode_from_ismn10_to_ismn13(upc):
 upc = str(upc);
 ismn13 = print_ismn13_barcode(convert_barcode_from_ismn10_to_ismn13(upc));
 return ismn13;
def print_convert_barcode_from_ismn13_to_ismn10(upc):
 upc = str(upc);
 ismn10 = print_ismn10_barcode(convert_barcode_from_ismn13_to_ismn10(upc));
 return ismn10;

'''
// Get variable weight price checksum for UPC-A
// Source: http://wiki.answers.com/Q/How_does_a_price_embedded_bar_code_work
// Source: http://en.wikipedia.org/wiki/Universal_Product_Code#Prefixes
// Source: http://barcodes.gs1us.org/GS1%20US%20BarCodes%20and%20eCom%20-%20The%20Global%20Language%20of%20Business.htm
'''
def make_upca_vw_to_upca_barcode(code, price):
 code = str(code);
 price = str(price);
 if(len(code)>5):
  if(re.findall("^(\d{5})", code)):
   code_matches = re.findall("^(\d{5})", code);
   code = code_matches[0];
 if(len(price)>4):
  if(re.findall("^(\d{4})", price)):
   price_matches = re.findall("^(\d{4})", price);
   price = price_matches[0];
 pricecs = str(upcean.validate.get_vw_price_checksum(price));
 vwupc = "2"+code+pricecs+price.zfill(4);
 vwupc = vwupc+str(upcean.validate.validate_upca_checksum(vwupc, True));
 return vwupc;
def make_vw_to_upca_barcode(code, price):
 return make_upca_vw_to_upca_barcode(code, price);
def make_upca_vw_to_ean13_barcode(code, price):
 code = str(code);
 price = str(price);
 vwean13 = convert_barcode_from_upca_to_ean13(make_upca_vw_to_upca_barcode(code, price));
 return vwean13;
def make_vw_to_ean13_barcode(code, price):
 return make_upca_vw_to_ean13_barcode(code, price);
def make_upca_vw_to_itf14_barcode(code, price):
 code = str(code);
 price = str(price);
 vwitf14 = convert_barcode_from_upca_to_itf14(make_upca_vw_to_upca_barcode(code, price));
 return vwitf14;
def make_vw_to_itf14_barcode(code, price):
 return make_upca_vw_to_itf14_barcode(code, price);

'''
// Get variable weight price checksum for EAN-13
// Source: https://softmatic.com/barcode-ean-13.html#ean-country
'''
def make_ean13_vw_to_ean13_barcode(numbersystem, code, price):
 code = str(code);
 price = str(price);
 numbersystem = str(numbersystem);
 if(len(numbersystem)>1):
  if(re.findall("^(\d{1})", numbersystem)):
   ns_matches = re.findall("^(\d{1})", numbersystem);
   numbersystem = ns_matches[0];
 if(len(code)>5):
  if(re.findall("^(\d{5})", code)):
   code_matches = re.findall("^(\d{5})", code);
   code = code_matches[0];
 if(len(price)>5):
  if(re.findall("^(\d{5})", price)):
   price_matches = re.findall("^(\d{5})", price);
   price = price_matches[0];
 vwupc = "2"+numbersystem+code+price.zfill(5);
 vwupc = vwupc+str(upcean.validate.validate_ean13_checksum(vwupc, True));
 return vwupc;
def make_ean13_vw_to_itf14_barcode(numbersystem, code, price):
 code = str(code);
 price = str(price);
 vwitf14 = convert_barcode_from_upca_to_itf14(make_ean13_vw_to_upca_barcode(numbersystem, code, price));
 return vwitf14;

def make_goodwill_to_upca_barcode(code, price):
 code = str(code);
 price = str(price);
 if(len(code)>5):
  if(re.findall("^(\d{5})", code)):
   code_matches = re.findall("^(\d{5})", code);
   code = code_matches[0];
 if(len(price)>5):
  if(re.findall("^(\d{5})", price)):
   price_matches = re.findall("^(\d{5})", price);
   price = price_matches[0];
 vwupc = "4"+code+price.zfill(5);
 vwupc = vwupc+str(upcean.validate.validate_upca_checksum(vwupc, True));
 return vwupc;
def make_goodwill_to_ean13_barcode(code, price):
 code = str(code);
 price = str(price);
 vwean13 = convert_barcode_from_upca_to_ean13(make_goodwill_to_upca_barcode(code, price));
 return vwean13;
def make_goodwill_to_itf14_barcode(code, price):
 code = str(code);
 price = str(price);
 vwitf14 = convert_barcode_from_upca_to_itf14(make_goodwill_to_upca_barcode(code, price));
 return vwitf14;

def make_coupon_to_upca_barcode(numbersystem, manufacturer, family, value):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 family = str(family);
 value = str(value);
 if(int(numbersystem)!=5 and int(numbersystem)!=9):
  numbersystem = "5";
 if(len(manufacturer)>5):
  fix_matches = re.findall("^(\d{5})", manufacturer); 
  upc = fix_matches[0];
 if(len(family)>3):
  fix_matches = re.findall("^(\d{3})", family); 
  upc = fix_matches[0];
 if(len(value)>2):
  fix_matches = re.findall("^(\d{2})", value); 
  upc = fix_matches[0];
 couponupca = numbersystem+manufacturer+family+value;
 couponupca = couponupca+str(upcean.validate.validate_upca_checksum(couponupca, True));
 return couponupca;
def make_coupon_to_ean13_barcode(numbersystem, manufacturer, family, value):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 family = str(family);
 value = str(value);
 couponean13 = convert_barcode_from_upca_to_ean13(make_coupon_to_upca_barcode(numbersystem, manufacturer, family, value));
 return couponean13;
def make_coupon_to_itf14_barcode(numbersystem, manufacturer, family, value):
 numbersystem = str(numbersystem);
 manufacturer = str(manufacturer);
 family = str(family);
 value = str(value);
 couponitf14 = convert_barcode_from_upca_to_itf14(make_coupon_to_upca_barcode(numbersystem, manufacturer, family, value));
 return couponitf14;

'''
// NDC (National Drug Codes)
// Source: http://www.drugs.com/ndc.html
// Source: http://www.wikihow.com/Read-12-Digit-UPC-Barcodes
'''
def make_ndc_to_upca_barcode(labeler, product, package):
 labeler = str(labeler);
 product = str(product);
 package = str(package);
 if(len(labeler)>4):
  if(re.findall("^(\d{4})", labeler)):
   labeler_matches = re.findall("^(\d{4})", labeler);
   labeler = labeler_matches[0];
 if(len(product)>4):
  if(re.findall("^(\d{4})", product)):
   product_matches = re.findall("^(\d{4})", product);
   product = product_matches[0];
 if(len(package)>2):
  if(re.findall("^(\d{2})", package)):
   package_matches = re.findall("^(\d{2})", package);
   package = package_matches[0];
 ndcupc = "3"+labeler+product+package;
 ndcupc = ndcupc+str(upcean.validate.validate_upca_checksum(ndcupc, True));
 return ndcupc;
def make_ndc_to_ean13_barcode(labeler, product, package):
 labeler = str(labeler);
 product = str(product);
 package = str(package);
 ndcean13 = convert_barcode_from_upca_to_ean13(make_ndc_to_upca_barcode(labeler, product, package));
 return ndcean13;
def make_ndc_to_itf14_barcode(labeler, product, package):
 labeler = str(labeler);
 product = str(product);
 package = str(package);
 ndcitf14 = convert_barcode_from_upca_to_itf14(make_ndc_to_upca_barcode(labeler, product, package));
 return ndcitf14;

def convert_barcode_from_ndc_to_upca(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 if(len(upc)>10):
  fix_matches = re.findall("^(\d{10})", upc); 
  upc = fix_matches[0];
 ndcupca = "3"+upc+str(upcean.validate.validate_upca_checksum("3"+upc,True)); 
 return ndcupca;
def convert_barcode_from_upca_to_ndc(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 if(not upcean.validate.validate_upca_checksum(upc)):
  return False;
 if(not re.findall("^3(\d{10})", upc)):
  return False;
 if(re.findall("^3(\d{10})", upc)):
  upc_matches = re.findall("^3(\d{10})", upc);
  ndc = upc_matches[0];
 return ndc;
def convert_barcode_from_ndc_to_ean13(upc):
 upc = str(upc);
 ndcean13 = convert_barcode_from_upca_to_ean13(convert_barcode_from_ndc_to_upca(upc));
 return ndcean13;
def convert_barcode_from_ndc_to_itf14(upc):
 upc = str(upc);
 ndcitf14 = convert_barcode_from_upca_to_itf14(convert_barcode_from_ndc_to_upca(upc));
 return ndcitf14;
def print_ndc_barcode(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 if(len(upc)>10):
  fix_matches = re.findall("^(\d{10})", upc); 
  upc = fix_matches[0];
 if(len(upc)>10 or len(upc)<10):
  return False;
 if(not re.findall("^(\d{4})(\d{4})(\d{2})", upc)):
  return False;
 ndc_matches = re.findall("^(\d{4})(\d{4})(\d{2})", upc);
 ndc_matches = ndc_matches[0];
 ndc = ndc_matches[0]+"-"+ndc_matches[1]+"-"+ndc_matches[2];
 return ndc;
def print_convert_barcode_from_upca_to_ndc(upc):
 upc = str(upc);
 ndc = print_ndc_barcode(convert_barcode_from_upca_to_ndc(upc));
 return ndc;



# -*- coding: utf-8 -*-
'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: shortcuts.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import upcean.validate.validate, upcean.support;

'''
// Shortcut Codes by Kazuki Przyborowski
// validate
'''
def validate_checksum(bctype, upc, return_check=False):
 if(bctype not in upcean.support.supported_barcodes("tuple")):
  return False;
 if(hasattr(upcean.validate.validate, "validate_"+bctype+"_checksum") and callable(getattr(upcean.validate.validate, "validate_"+bctype+"_checksum"))):
  return getattr(upcean.validate.validate, "validate_"+bctype+"_checksum")(upc,return_check);
 if(not hasattr(upcean.validate.validate, "validate_"+bctype+"_checksum") or not callable(getattr(upcean.validate.validate, "validate_"+bctype+"_checksum"))):
  return False;
 return False;
def get_checksum(bctype, upc):
 if(bctype not in upcean.support.supported_barcodes("tuple")):
  return False;
 if(hasattr(upcean.validate.validate, "get_"+bctype+"_checksum") and callable(getattr(upcean.validate.validate, "get_"+bctype+"_checksum"))):
  return getattr(upcean.validate.validate, "get_"+bctype+"_checksum")(upc);
 if(not hasattr(upcean.validate.validate, "get_"+bctype+"_checksum") or not callable(getattr(upcean.validate.validate, "get_"+bctype+"_checksum"))):
  return False;
 return False;
def fix_checksum(bctype, upc):
 if(bctype not in upcean.support.supported_barcodes("tuple")):
  return False;
 if(hasattr(upcean.validate.validate, "fix_"+bctype+"_checksum") and callable(getattr(upcean.validate.validate, "fix_"+bctype+"_checksum"))):
  return getattr(upcean.validate.validate, "fix_"+bctype+"_checksum")(upc);
 if(not hasattr(upcean.validate.validate, "fix_"+bctype+"_checksum") or not callable(getattr(upcean.validate.validate, "fix_"+bctype+"_checksum"))):
  return False;
 return False;



# -*- coding: utf-8 -*-
'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2020 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2011-2020 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: barcode.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import upcean.support, upcean.getprefix.getprefix;

''' // Code for making EAN-2 supplement by Kazuki Przyborowski '''
from upcean.barcodes.ean2 import *;
''' // Code for making EAN-5 supplement by Kazuki Przyborowski '''
from upcean.barcodes.ean5 import *;
''' // Code for making UPC-A by Kazuki Przyborowski '''
from upcean.barcodes.upca import *;
''' // Code for making Goodwill Barcodes by Kazuki Przyborowski '''
from upcean.barcodes.goodwill import *;
''' // Code for making UPC-E by Kazuki Przyborowski '''
from upcean.barcodes.upce import *;
''' // Code for making EAN-13 by Kazuki Przyborowski '''
from upcean.barcodes.ean13 import *;
''' // Code for making EAN-8 by Kazuki Przyborowski '''
from upcean.barcodes.ean8 import *;
''' // Code for making Standard 2 of 5 by Kazuki Przyborowski '''
from upcean.barcodes.stf import *;
''' // Code for making Interleaved 2 of 5 by Kazuki Przyborowski '''
from upcean.barcodes.itf import *;
''' // Code for making ITF-14 by Kazuki Przyborowski '''
from upcean.barcodes.itf14 import *;
''' // Code for making Code 11 by Kazuki Przyborowski '''
from upcean.barcodes.code11 import *;
''' // Code for making Code 39 by Kazuki Przyborowski '''
from upcean.barcodes.code39 import *;
''' // Code for making Code 93 by Kazuki Przyborowski '''
from upcean.barcodes.code93 import *;
''' // Code for making Code 128 by Kazuki Przyborowski '''
from upcean.barcodes.code128 import *;
''' // Code for making Codabar by Kazuki Przyborowski '''
from upcean.barcodes.codabar import *;
''' // Code for making Plessey by Kazuki Przyborowski '''
from upcean.barcodes.plessey import *;
''' // Code for making Modified Plessey by Kazuki Przyborowski '''
from upcean.barcodes.msi import *;

def validate_create_upca_barcode(upc,outfile="./upca.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>12 or len(upc)<12):
  return False;
 if(not upcean.validate.validate_upca_checksum(upc)):
  return False;
 return create_upca_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_upca_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_upca_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def validate_create_goodwill_barcode(upc,outfile="./goodwill.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>12 or len(upc)<12):
  return False;
 if(not upcean.validate.validate_upca_checksum(upc)):
  return False;
 if(not upcean.getprefix.getprefix.get_goodwill_upca_barcode_info(upc)):
  return False;
 return create_goodwill_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_goodwill_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_goodwill_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def validate_create_upce_barcode(upc,outfile="./upce.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>8 or len(upc)<8):
  return False;
 if(not upcean.validate.validate_upce_checksum(upc)):
  return False;
 return create_upce_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_upce_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_upce_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def validate_create_ean13_barcode(upc,outfile="./ean13.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>13 or len(upc)<13):
  return False;
 if(not upcean.validate.validate_ean13_checksum(upc)):
  return False;
 return create_ean13_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_ean13_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_ean13_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def validate_create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>8 or len(upc)<8):
  return False;
 if(not upcean.validate.validate_upce_checksum(upc)):
  return False;
 return create_upce_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_ean8_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_ean8_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def validate_create_itf_barcode(upc,outfile="./itf.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>14 or len(upc)<14):
  return False;
 if(not upcean.validate.validate_itf14_checksum(upc)):
  return False;
 return create_itf_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_itf_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_itf_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def validate_create_itf6_barcode(upc,outfile="./itf6.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>6 or len(upc)<6):
  return False;
 if(not upcean.validate.validate_itf6_checksum(upc)):
  return False;
 return create_itf6_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_itf6_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_itf6_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def validate_create_itf14_barcode(upc,outfile="./itf14.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>14 or len(upc)<14):
  return False;
 if(not upcean.validate.validate_itf14_checksum(upc)):
  return False;
 return create_itf14_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def validate_draw_itf14_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return validate_create_itf14_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_upca_barcode(upc,outfile="./upca.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>12 or len(upc)<11):
  return False;
 upc = upcean.validate.fix_upca_checksum(upc);
 return create_upca_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_upca_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_upca_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_goodwill_barcode(upc,outfile="./goodwill.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>12 or len(upc)<11):
  return False;
 upc = upcean.validate.fix_upca_checksum(upc);
 if(not upcean.getprefix.getprefix.get_goodwill_upca_barcode_info(upc)):
  return False;
 return create_goodwill_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_goodwill_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_goodwill_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_upce_barcode(upc,outfile="./upce.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>8 or len(upc)<7):
  return False;
 upc = upcean.validate.fix_upce_checksum(upc);
 return create_upce_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_upce_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_upce_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_ean13_barcode(upc,outfile="./ean13.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>13 or len(upc)<12):
  return False;
 upc = upcean.validate.fix_ean13_checksum(upc);
 return create_ean13_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_ean13_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_ean13_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>8 or len(upc)<7):
  return False;
 upc = upcean.validate.fix_ean8_checksum(upc);
 return create_upce_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_ean8_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_ean8_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_itf_barcode(upc,outfile="./itf.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>14 or len(upc)<13):
  return False;
 upc = upcean.validate.fix_itf14_checksum(upc);
 return create_itf_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_itf_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_itf_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_itf6_barcode(upc,outfile="./itf6.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>6 or len(upc)<5):
  return False;
 upc = upcean.validate.fix_itf6_checksum(upc);
 return create_itf6_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_itf6_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_itf6_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);

def fix_create_itf14_barcode(upc,outfile="./itf14.png",resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 if(len(upc)>14 or len(upc)<13):
  return False;
 upc = upcean.validate.fix_itf14_checksum(upc);
 return create_itf14_barcode(upc,outfile,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
def fix_draw_itf14_barcode(upc,resize=1,hideinfo=(False, False, False),barheight=(48, 54),barwidth=1,textxy=(1, 1, 1),barcolor=((0, 0, 0), (0, 0, 0), (255, 255, 255)), imageoutlib="pillow"):
 return fix_create_itf14_barcode(upc,None,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);



# -*- coding: utf-8 -*-
'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: countries.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import sys, re, upcean.validate;

'''
// Get GS1 Prefix for EAN-13 EAN-9 barcodes
// Source: http://en.wikipedia.org/wiki/List_of_GS1_country_codes
'''
def get_gs1_prefix(upc):
 upc = str(upc);
 if(re.findall("^(\d{12})", upc)):
  upc = "0"+upc;
 if(re.findall("^(\d{1})$", upc)):
  upc = upc+"00000000000";
  upc = upc+str(upcean.validate.get_ean13_checksum(upc));
 if(re.findall("^(\d{2})$", upc)):
  upc = upc+"0000000000";
  upc = upc+str(upcean.validate.get_ean13_checksum(upc));
 if(re.findall("^(\d{3})$", upc)):
  upc = upc+"000000000";
  upc = upc+str(upcean.validate.get_ean13_checksum(upc));
 if(re.findall("^0(\d{3}\d{10})", upc)):
  fix_ean = re.findall("^0(\d{3}\d{10})", upc);
  upc = fix_ean[0];
 if(not re.findall("^(\d{3}\d{5}|\d{3}\d{10})$", upc)):
  return False;
 if(re.findall("^(\d{3}\d{10})$", upc) and not upcean.validate.validate_ean13_checksum(upc)):
  return False;
 if(re.findall("^(\d{3}\d{5})$", upc) and not upcean.validate.validate_ean8_checksum(upc)):
  return False;
 if(re.findall("^(0[0-1][0-9])", upc)):
  return "United States and Canada";
 if(re.findall("^(02[0-9])", upc)):
  return "Restricted distribution";
 if(re.findall("^(03[0-9])", upc)):
  return "United States drugs";
 if(re.findall("^(04[0-9])", upc)):
  return "Restricted distribution";
 if(re.findall("^(05[0-9])", upc)):
  return "Coupons";
 if(re.findall("^(0[6-9][0-9])", upc)):
  return "United States and Canada";
 if(re.findall("^(1[0-3][0-9])", upc)):
  return "United States";
 if(re.findall("^(2[0-9][0-9])", upc)):
  return "Restricted distribution";
 if(re.findall("^(3[0-7][0-9])", upc)):
  return "France and Monaco";
 if(re.findall("^(380)", upc)):
  return "Bulgaria";
 if(re.findall("^(383)", upc)):
  return "Slovenia";
 if(re.findall("^(385)", upc)):
  return "Croatia";
 if(re.findall("^(387)", upc)):
  return "Bosnia and Herzegovina";
 if(re.findall("^(389)", upc)):
  return "Montenegro";
 if(re.findall("^(390)", upc)):
  return "Kosovo";
 if(re.findall("^(4[0-3][0-9]|440)", upc)):
  return "Germany";
 if(re.findall("^(4[0-5][0-9])", upc)):
  return "Japan";
 if(re.findall("^(46[0-9])", upc)):
  return "Russia";
 if(re.findall("^(470)", upc)):
  return "Kyrgyzstan";
 if(re.findall("^(471)", upc)):
  return "Taiwan";
 if(re.findall("^(474)", upc)):
  return "Estonia";
 if(re.findall("^(475)", upc)):
  return "Latvia";
 if(re.findall("^(476)", upc)):
  return "Azerbaijan";
 if(re.findall("^(477)", upc)):
  return "Lithuania";
 if(re.findall("^(478)", upc)):
  return "Uzbekistan";
 if(re.findall("^(479)", upc)):
  return "Sri Lanka";
 if(re.findall("^(480)", upc)):
  return "Philippines";
 if(re.findall("^(481)", upc)):
  return "Belarus";
 if(re.findall("^(482)", upc)):
  return "Ukraine";
 if(re.findall("^(483)", upc)):
  return "Turkmenistan";
 if(re.findall("^(484)", upc)):
  return "Moldova";
 if(re.findall("^(485)", upc)):
  return "Armenia";
 if(re.findall("^(486)", upc)):
  return "Georgia";
 if(re.findall("^(487)", upc)):
  return "Kazakhstan";
 if(re.findall("^(488)", upc)):
  return "Tajikistan";
 if(re.findall("^(489)", upc)):
  return "Hong Kong SAR";
 if(re.findall("^(49[0-9])", upc)):
  return "Japan";
 if(re.findall("^(50[0-9])", upc)):
  return "United Kingdom";
 if(re.findall("^(52[0-1])", upc)):
  return "Greece";
 if(re.findall("^(528)", upc)):
  return "Lebanon";
 if(re.findall("^(529)", upc)):
  return "Cyprus";
 if(re.findall("^(530)", upc)):
  return "Albania";
 if(re.findall("^(531)", upc)):
  return "North Macedonia";
 if(re.findall("^(535)", upc)):
  return "Malta";
 if(re.findall("^(539)", upc)):
  return "Ireland";
 if(re.findall("^(54[0-9])", upc)):
  return "Belgium and Luxembourg";
 if(re.findall("^(560)", upc)):
  return "Portugal";
 if(re.findall("^(569)", upc)):
  return "Iceland";
 if(re.findall("^(57[0-9])", upc)):
  return "Denmark, Faroe Islands and Greenland";
 if(re.findall("^(590)", upc)):
  return "Poland";
 if(re.findall("^(594)", upc)):
  return "Romania";
 if(re.findall("^(599)", upc)):
  return "Hungary";
 if(re.findall("^(60[0-1])", upc)):
  return "South Africa";
 if(re.findall("^(603)", upc)):
  return "Ghana";
 if(re.findall("^(604)", upc)):
  return "Senegal";
 if(re.findall("^(608)", upc)):
  return "Bahrain";
 if(re.findall("^(609)", upc)):
  return "Mauritius";
 if(re.findall("^(611)", upc)):
  return "Morocco";
 if(re.findall("^(613)", upc)):
  return "Algeria";
 if(re.findall("^(615)", upc)):
  return "Nigeria";
 if(re.findall("^(616)", upc)):
  return "Kenya";
 if(re.findall("^(618)", upc)):
  return "Côte d'Ivoire";
 if(re.findall("^(619)", upc)):
  return "Tunisia";
 if(re.findall("^(620)", upc)):
  return "Tanzania";
 if(re.findall("^(621)", upc)):
  return "Syria";
 if(re.findall("^(622)", upc)):
  return "Egypt";
 if(re.findall("^(623)", upc)):
  return "Brunei";
 if(re.findall("^(624)", upc)):
  return "Libya";
 if(re.findall("^(625)", upc)):
  return "Jordan";
 if(re.findall("^(626)", upc)):
  return "Iran";
 if(re.findall("^(627)", upc)):
  return "Kuwait";
 if(re.findall("^(628)", upc)):
  return "Saudi Arabia";
 if(re.findall("^(629)", upc)):
  return "United Arab Emirates";
 if(re.findall("^(630)", upc)):
  return "Qatar";
 if(re.findall("^(631)", upc)):
  return "Namibia";
 if(re.findall("^(64[0-9])", upc)):
  return "Finland";
 if(re.findall("^(69[0-5])", upc)):
  return "China";
 if(re.findall("^(70[0-9])", upc)):
  return "Norway";
 if(re.findall("^(729)", upc)):
  return "Israel";
 if(re.findall("^(73[0-9])", upc)):
  return "Sweden";
 if(re.findall("^(740)", upc)):
  return "Guatemala";
 if(re.findall("^(741)", upc)):
  return "El Salvador";
 if(re.findall("^(742)", upc)):
  return "Honduras";
 if(re.findall("^(743)", upc)):
  return "Nicaragua";
 if(re.findall("^(744)", upc)):
  return "Costa Rica";
 if(re.findall("^(745)", upc)):
  return "Panama";
 if(re.findall("^(746)", upc)):
  return "Dominican Republic";
 if(re.findall("^(750)", upc)):
  return "Mexico";
 if(re.findall("^(75[4-5])", upc)):
  return "Canada";
 if(re.findall("^(759)", upc)):
  return "Venezuela";
 if(re.findall("^(76[0-9])", upc)):
  return "Switzerland and Liechtenstein";
 if(re.findall("^(77[0-1])", upc)):
  return "Colombia";
 if(re.findall("^(773)", upc)):
  return "Uruguay";
 if(re.findall("^(775)", upc)):
  return "Peru";
 if(re.findall("^(777)", upc)):
  return "Bolivia";
 if(re.findall("^(77[8-9])", upc)):
  return "Argentina";
 if(re.findall("^(780)", upc)):
  return "Chile";
 if(re.findall("^(784)", upc)):
  return "Paraguay";
 if(re.findall("^(786)", upc)):
  return "Ecuador";
 if(re.findall("^(789|790)", upc)):
  return "Brazil";
 if(re.findall("^(8[0-3][0-9])", upc)):
  return "Italy, San Marino and Vatican City";
 if(re.findall("^(84[0-9])", upc)):
  return "Spain and Andorra";
 if(re.findall("^(850)", upc)):
  return "Cuba";
 if(re.findall("^(858)", upc)):
  return "Slovakia";
 if(re.findall("^(859)", upc)):
  return "Czechia";
 if(re.findall("^(860)", upc)):
  return "Serbia";
 if(re.findall("^(865)", upc)):
  return "Mongolia";
 if(re.findall("^(867)", upc)):
  return "North Korea";
 if(re.findall("^(86[8-9])", upc)):
  return "Türkiye";
 if(re.findall("^(87[0-9])", upc)):
  return "Netherlands";
 if(re.findall("^(880)", upc)):
  return "South Korea";
 if(re.findall("^(883)", upc)):
  return "Myanmar";
 if(re.findall("^(884)", upc)):
  return "Cambodia";
 if(re.findall("^(885)", upc)):
  return "Thailand";
 if(re.findall("^(888)", upc)):
  return "Singapore";
 if(re.findall("^(890)", upc)):
  return "India";
 if(re.findall("^(893)", upc)):
  return "Vietnam";
 if(re.findall("^(894)", upc)):
  return "Bangladesh";
 if(re.findall("^(896)", upc)):
  return "Pakistan";
 if(re.findall("^(899)", upc)):
  return "Indonesia";
 if(re.findall("^(9[0-1][0-9])", upc)):
  return "Austria";
 if(re.findall("^(93[0-9])", upc)):
  return "Australia";
 if(re.findall("^(94[0-9])", upc)):
  return "New Zealand";
 if(re.findall("^(950)", upc)):
  return "GS1 Global Office: Special applications";
 if(re.findall("^(951)", upc)):
  return "EPCglobal: Special applications";
 if(re.findall("^(955)", upc)):
  return "Malaysia";
 if(re.findall("^(958)", upc)):
  return "Macau";
 if(re.findall("^(960)", upc)):
  return "GS1 UK: GTIN-8 allocations";
 if(re.findall("^(96[1-9])", upc)):
  return "GS1 Global Office: GTIN-8 allocations";
 if(re.findall("^(977)", upc)):
  return "Serial publications (ISSN)";
 if(re.findall("^(97[8-9])", upc)):
  return "Bookland (ISBN)";
 if(re.findall("^(980)", upc)):
  return "Refund receipts";
 if(re.findall("^(98[1-3])", upc)):
  return "Common Currency Coupons";
 if(re.findall("^(99[0-9])", upc)):
  return "Coupons";
 '''
 // Reserved for future use
 '''
 if(re.findall("^(1[4-9][0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(381|382|384|386|388)", upc)):
  return "Reserved for future use";
 if(re.findall("^(39[0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(44[1-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(472|473|483)", upc)):
  return "Reserved for future use";
 if(re.findall("^(51[0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(52[1-7])", upc)):
  return "Reserved for future use";
 if(re.findall("^(53[2-4])", upc)):
  return "Reserved for future use";
 if(re.findall("^(53[6-8])", upc)):
  return "Reserved for future use";
 if(re.findall("^(55[0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(56[1-8])", upc)):
  return "Reserved for future use";
 if(re.findall("^(58[0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(59[1-3])", upc)):
  return "Reserved for future use";
 if(re.findall("^(59[5-8])", upc)):
  return "Reserved for future use";
 if(re.findall("^(602)", upc)):
  return "Reserved for future use";
 if(re.findall("^(60[5-7])", upc)):
  return "Reserved for future use";
 if(re.findall("^(610|612|614|617|620|623)", upc)):
  return "Reserved for future use";
 if(re.findall("^(63[0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(6[5-8][0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(69[6-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(71[0-9]|72[0-8])", upc)):
  return "Reserved for future use";
 if(re.findall("^(74[7-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(75[1-3])", upc)):
  return "Reserved for future use";
 if(re.findall("^(75[6-8])", upc)):
  return "Reserved for future use";
 if(re.findall("^(772|774|776|778)", upc)):
  return "Reserved for future use";
 if(re.findall("^(78[1-3])", upc)):
  return "Reserved for future use";
 if(re.findall("^(785|787|788)", upc)):
  return "Reserved for future use";
 if(re.findall("^(79[1-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(85[1-7])", upc)):
  return "Reserved for future use";
 if(re.findall("^(86[1-4])", upc)):
  return "Reserved for future use";
 if(re.findall("^(866)", upc)):
  return "Reserved for future use";
 if(re.findall("^(88[1-3])", upc)):
  return "Reserved for future use";
 if(re.findall("^(886|887|889|891|892|895|897|898)", upc)):
  return "Reserved for future use";
 if(re.findall("^(92[0-9])", upc)):
  return "Reserved for future use";
 if(re.findall("^(95[2-4])", upc)):
  return "Reserved for future use";
 if(re.findall("^(956|957|959)", upc)):
  return "Reserved for future use";
 if(re.findall("^(96[0-9]|97[0-6])", upc)):
  return "Reserved for future use";
 if(re.findall("^(98[4-9])", upc)):
  return "Reserved for future use";
 return False;

'''
// Get ISBN identifier groups
// Source: http://en.wikipedia.org/wiki/List_of_ISBN_identifier_groups
'''
def get_isbn_identifier(upc):
 upc = str(upc);
 upc = upc.replace("-", "");
 upc = upc.replace(" ", "");
 if(len(upc)>10):
  fix_matches = re.findall("^(\d{9})(\d{1}|X{1})", upc); 
  fix_matches = fix_matches[0]
  upc = fix_matches[0]+fix_matches[1];
 if(len(upc)>10 or len(upc)<10):
  return False;
 if(re.findall("^99972", upc)):
  return "Faroe Islands";
 if(re.findall("^99971", upc)):
  return "Myanmar";
 if(re.findall("^99970", upc)):
  return "Haiti";
 if(re.findall("^99969", upc)):
  return "Oman";
 if(re.findall("^99968", upc)):
  return "Botswana";
 if(re.findall("^99967", upc)):
  return "Paraguay";
 if(re.findall("^99966", upc)):
  return "Kuwait";
 if(re.findall("^99965", upc)):
  return "Macau";
 if(re.findall("^99964", upc)):
  return "Nicaragua";
 if(re.findall("^99963", upc)):
  return "Cambodia";
 if(re.findall("^99962", upc)):
  return "Mongolia";
 if(re.findall("^99961", upc)):
  return "El Salvador";
 if(re.findall("^99960", upc)):
  return "Malawi";
 if(re.findall("^99959", upc)):
  return "Luxembourg";
 if(re.findall("^99958", upc)):
  return "Bahrain";
 if(re.findall("^99957", upc)):
  return "Malta";
 if(re.findall("^99956", upc)):
  return "Albania";
 if(re.findall("^99955", upc)):
  return "Republika Srpska";
 if(re.findall("^99954", upc)):
  return "Bolivia";
 if(re.findall("^99953", upc)):
  return "Paraguay";
 if(re.findall("^99952", upc)):
  return "Mali";
 if(re.findall("^99951", upc)):
  return "Democratic Republic of Congo";
 if(re.findall("^99950", upc)):
  return "Cambodia";
 if(re.findall("^99949", upc)):
  return "Mauritius";
 if(re.findall("^99948", upc)):
  return "Eritrea";
 if(re.findall("^99947", upc)):
  return "Tajikistan";
 if(re.findall("^99946", upc)):
  return "Nepal";
 if(re.findall("^99945", upc)):
  return "Namibia";
 if(re.findall("^99944", upc)):
  return "Ethiopia";
 if(re.findall("^99943", upc)):
  return "Albania";
 if(re.findall("^99942", upc)):
  return "Sudan";
 if(re.findall("^99941", upc)):
  return "Armenia";
 if(re.findall("^99939", upc)):
  return "Guatemala";
 if(re.findall("^99938", upc)):
  return "Republika Srpska";
 if(re.findall("^99937", upc)):
  return "Macau";
 if(re.findall("^99936", upc)):
  return "Bhutan";
 if(re.findall("^99935", upc)):
  return "Haiti";
 if(re.findall("^99934", upc)):
  return "Dominican republic";
 if(re.findall("^99933", upc)):
  return "Nepal";
 if(re.findall("^99932", upc)):
  return "Malta";
 if(re.findall("^99931", upc)):
  return "Seychelles";
 if(re.findall("^99930", upc)):
  return "Armenia";
 if(re.findall("^99929", upc)):
  return "Mongolia";
 if(re.findall("^99928", upc)):
  return "Georgia";
 if(re.findall("^99927", upc)):
  return "Albania";
 if(re.findall("^99926", upc)):
  return "Honduras";
 if(re.findall("^99925", upc)):
  return "Paraguay";
 if(re.findall("^99924", upc)):
  return "Nicaragua";
 if(re.findall("^99923", upc)):
  return "El Salvador";
 if(re.findall("^99922", upc)):
  return "Guatemala";
 if(re.findall("^99921", upc)):
  return "Qatar";
 if(re.findall("^99920", upc)):
  return "Andorra";
 if(re.findall("^99919", upc)):
  return "Benin";
 if(re.findall("^99918", upc)):
  return "Faroe Islands";
 if(re.findall("^99917", upc)):
  return "Brunei Darussalam";
 if(re.findall("^99916", upc)):
  return "Namibia";
 if(re.findall("^99915", upc)):
  return "Maldives";
 if(re.findall("^99914", upc)):
  return "Suriname";
 if(re.findall("^99913", upc)):
  return "Andorra";
 if(re.findall("^99912", upc)):
  return "Botsana";
 if(re.findall("^99911", upc)):
  return "Lesotho";
 if(re.findall("^99910", upc)):
  return "Sierra Leone";
 if(re.findall("^99909", upc)):
  return "Malta";
 if(re.findall("^99908", upc)):
  return "Malawi";
 if(re.findall("^99906", upc)):
  return "Kuwait";
 if(re.findall("^99905", upc)):
  return "Bolivia";
 if(re.findall("^99904", upc)):
  return "Netherland Antilles, and Aruba";
 if(re.findall("^99903", upc)):
  return "Mauritius";
 if(re.findall("^99902", upc)):
  return "Gabon";
 if(re.findall("^99901", upc)):
  return "Bahrain";
 if(re.findall("^9989", upc)):
  return "Macedonia";
 if(re.findall("^9988", upc)):
  return "Ghana";
 if(re.findall("^9987", upc)):
  return "Tanzania";
 if(re.findall("^9986", upc)):
  return "Lithuania";
 if(re.findall("^9985", upc)):
  return "Estonia";
 if(re.findall("^9984", upc)):
  return "Latvia";
 if(re.findall("^9983", upc)):
  return "Gambia";
 if(re.findall("^9982", upc)):
  return "Zambia";
 if(re.findall("^9981", upc)):
  return "Morocco";
 if(re.findall("^9980", upc)):
  return "Papua New Guinea";
 if(re.findall("^9979", upc)):
  return "Iceland";
 if(re.findall("^9978", upc)):
  return "Ecuador";
 if(re.findall("^9977", upc)):
  return "Costa Rica";
 if(re.findall("^9976", upc)):
  return "Tanzania";
 if(re.findall("^9975", upc)):
  return "Moldova";
 if(re.findall("^9974", upc)):
  return "Uruguay";
 if(re.findall("^9973", upc)):
  return "Tunisia";
 if(re.findall("^9972", upc)):
  return "Peru";
 if(re.findall("^9971", upc)):
  return "Singapore";
 if(re.findall("^9970", upc)):
  return "Uganda";
 if(re.findall("^9968", upc)):
  return "Costa Rica";
 if(re.findall("^9967", upc)):
  return "Kyrgyzstan";
 if(re.findall("^9966", upc)):
  return "Kenya";
 if(re.findall("^9965", upc)):
  return "Kazakhstan";
 if(re.findall("^9964", upc)):
  return "Ghana";
 if(re.findall("^9963", upc)):
  return "Cyprus";
 if(re.findall("^9962", upc)):
  return "Panama";
 if(re.findall("^9961", upc)):
  return "Algeria";
 if(re.findall("^9960", upc)):
  return "Saudi Arabia";
 if(re.findall("^9959", upc)):
  return "Libya";
 if(re.findall("^9958", upc)):
  return "Bosnia and Herzegovina";
 if(re.findall("^9957", upc)):
  return "Jordan";
 if(re.findall("^9956", upc)):
  return "Cameroon";
 if(re.findall("^9955", upc)):
  return "Lithuania";
 if(re.findall("^9954", upc)):
  return "Morocco";
 if(re.findall("^9953", upc)):
  return "Lebanon";
 if(re.findall("^9952", upc)):
  return "Azerbaijan";
 if(re.findall("^9951", upc)):
  return "Kosovo";
 if(re.findall("^9950", upc)):
  return "Palestine";
 if(re.findall("^9949", upc)):
  return "Estonia";
 if(re.findall("^9948", upc)):
  return "United Arab Emirates";
 if(re.findall("^9947", upc)):
  return "Algeria";
 if(re.findall("^9946", upc)):
  return "North Korea";
 if(re.findall("^9945", upc)):
  return "Dominican Republic";
 if(re.findall("^9944", upc)):
  return "Turkey";
 if(re.findall("^9943", upc)):
  return "Uzbekistan";
 if(re.findall("^9942", upc)):
  return "Ecuador";
 if(re.findall("^9941", upc)):
  return "Georgia";
 if(re.findall("^9940", upc)):
  return "Montenegro";
 if(re.findall("^9939", upc)):
  return "Armenia";
 if(re.findall("^9937", upc)):
  return "Nepal";
 if(re.findall("^9936", upc)):
  return "Afghanistan";
 if(re.findall("^9935", upc)):
  return "Iceland";
 if(re.findall("^9934", upc)):
  return "Latvia";
 if(re.findall("^9933", upc)):
  return "Syria";
 if(re.findall("^9932", upc)):
  return "Laos";
 if(re.findall("^9931", upc)):
  return "Algeria";
 if(re.findall("^9930", upc)):
  return "Costa Rica";
 if(re.findall("^9929", upc)):
  return "Guatemala";
 if(re.findall("^9928", upc)):
  return "Albania";
 if(re.findall("^9927", upc)):
  return "Qatar";
 if(re.findall("^989", upc)):
  return "Portugal";
 if(re.findall("^988", upc)):
  return "Hong Kong";
 if(re.findall("^987", upc)):
  return "Argentina";
 if(re.findall("^986", upc)):
  return "Taiwan";
 if(re.findall("^985", upc)):
  return "Belarus";
 if(re.findall("^984", upc)):
  return "Bangladesh";
 if(re.findall("^983", upc)):
  return "Malaysia";
 if(re.findall("^982", upc)):
  return "South Pacific";
 if(re.findall("^981", upc)):
  return "Singapore";
 if(re.findall("^980", upc)):
  return "Venezuela";
 if(re.findall("^979", upc)):
  return "Indonesia";
 if(re.findall("^978", upc)):
  return "Nigeria";
 if(re.findall("^977", upc)):
  return "Egypt";
 if(re.findall("^976", upc)):
  return "CARICOM";
 if(re.findall("^975", upc)):
  return "Turkey";
 if(re.findall("^974", upc)):
  return "Thailand";
 if(re.findall("^973", upc)):
  return "Romania";
 if(re.findall("^972", upc)):
  return "Portugal";
 if(re.findall("^971", upc)):
  return "Philippines";
 if(re.findall("^970", upc)):
  return "Mexico";
 if(re.findall("^969", upc)):
  return "Pakistan";
 if(re.findall("^968", upc)):
  return "Mexico";
 if(re.findall("^967", upc)):
  return "Malaysia";
 if(re.findall("^966", upc)):
  return "Ukraine";
 if(re.findall("^965", upc)):
  return "Israel";
 if(re.findall("^964", upc)):
  return "Iran";
 if(re.findall("^963", upc)):
  return "Hungary";
 if(re.findall("^962", upc)):
  return "Hong Kong";
 if(re.findall("^961", upc)):
  return "Slovenia";
 if(re.findall("^960", upc)):
  return "Greece";
 if(re.findall("^959", upc)):
  return "Cuba";
 if(re.findall("^958", upc)):
  return "Colombia";
 if(re.findall("^957", upc)):
  return "Taiwan";
 if(re.findall("^956", upc)):
  return "Chile";
 if(re.findall("^955", upc)):
  return "Sri Lanka";
 if(re.findall("^954", upc)):
  return "Bulgaria";
 if(re.findall("^953", upc)):
  return "Croatia";
 if(re.findall("^952", upc)):
  return "Finland";
 if(re.findall("^951", upc)):
  return "Finland";
 if(re.findall("^950", upc)):
  return "Argentina";
 if(re.findall("^621", upc)):
  return "Philippines";
 if(re.findall("^620", upc)):
  return "Mauritius";
 if(re.findall("^619", upc)):
  return "Bulgaria";
 if(re.findall("^618", upc)):
  return "Greece";
 if(re.findall("^617", upc)):
  return "Ukraine";
 if(re.findall("^616", upc)):
  return "Thailand";
 if(re.findall("^615", upc)):
  return "Hungary";
 if(re.findall("^614", upc)):
  return "Lebanon";
 if(re.findall("^613", upc)):
  return "Mauritius";
 if(re.findall("^612", upc)):
  return "Peru";
 if(re.findall("^611", upc)):
  return "Thailand";
 if(re.findall("^609", upc)):
  return "Lithuania";
 if(re.findall("^608", upc)):
  return "Macedonia";
 if(re.findall("^607", upc)):
  return "Mexico";
 if(re.findall("^606", upc)):
  return "Romania";
 if(re.findall("^605", upc)):
  return "Turkey";
 if(re.findall("^604", upc)):
  return "Vietnam";
 if(re.findall("^603", upc)):
  return "Saudi Arabia";
 if(re.findall("^602", upc)):
  return "Indonesia";
 if(re.findall("^601", upc)):
  return "Kazakhstan";
 if(re.findall("^600", upc)):
  return "Iran";
 if(re.findall("^94", upc)):
  return "Netherlands";
 if(re.findall("^93", upc)):
  return "India";
 if(re.findall("^92", upc)):
  return "International NGO Publishers and EC Organizations";
 if(re.findall("^91", upc)):
  return "Sweden";
 if(re.findall("^90", upc)):
  return "Netherlands";
 if(re.findall("^89", upc)):
  return "Republic of Korea";
 if(re.findall("^88", upc)):
  return "Italy";
 if(re.findall("^87", upc)):
  return "Denmark";
 if(re.findall("^86", upc)):
  return "Serbia (shared)";
 if(re.findall("^85", upc)):
  return "Brazil";
 if(re.findall("^84", upc)):
  return "Spain";
 if(re.findall("^83", upc)):
  return "Poland";
 if(re.findall("^82", upc)):
  return "Norway";
 if(re.findall("^81", upc)):
  return "India";
 if(re.findall("^80", upc)):
  return "Czech Republic and Slovakia";
 if(re.findall("^7", upc)):
  return "China";
 if(re.findall("^5", upc)):
  return "Russia and former USSR";
 if(re.findall("^4", upc)):
  return "Japan";
 if(re.findall("^3", upc)):
  return "German";
 if(re.findall("^2", upc)):
  return "French";
 if(re.findall("^1", upc)):
  return "English";
 if(re.findall("^0", upc)):
  return "English";
 return False;



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: setup.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
'''

import re, os, sys, time, datetime, platform, pkg_resources;
from setuptools import setup, find_packages;

install_requires = [];
extras_requires = [];
# https://github.com/mapproxy/mapproxy/blob/master/setup.py
def pillow_installed():
 """Check if Pillow is installed"""
 pillow_req = pkg_resources.Requirement.parse('Pillow');
 try:
  pkg_resources.get_provider(pillow_req);
 except pkg_resources.DistributionNotFound:
  return False;
 else:
  return True;
# depend in Pillow if it is installed, otherwise depend on PIL
if pillow_installed():
 extras_requires.append('Pillow');
else:
 extras_requires.append('PIL');
extras_requires.append('pycairo');
extras_requires_dict = {'drawing_barcodes':  extras_requires}

pygenbuildinfo = True;
verinfofilename = os.path.realpath("."+os.path.sep+"upcean"+os.path.sep+"versioninfo.py");
verinfofile = open(verinfofilename, "r");
verinfodata = verinfofile.read();
verinfofile.close();
setuppy_verinfo_esc = re.escape("__version_info__ = (")+"(.*)"+re.escape(");");
setuppy_verinfo = re.findall(setuppy_verinfo_esc, verinfodata)[0];
setuppy_verinfo_exp = [vergetspt.strip().replace("\"", "") for vergetspt in setuppy_verinfo.split(',')];
setuppy_dateinfo_esc = re.escape("__version_date_info__ = (")+"(.*)"+re.escape(");");
setuppy_dateinfo = re.findall(setuppy_dateinfo_esc, verinfodata)[0];
setuppy_dateinfo_exp = [vergetspt.strip().replace("\"", "") for vergetspt in setuppy_dateinfo.split(',')];
pymodule = {};
pymodule['version'] = str(setuppy_verinfo_exp[0])+"."+str(setuppy_verinfo_exp[1])+"."+str(setuppy_verinfo_exp[2]);
pymodule['versionrc'] = int(setuppy_verinfo_exp[4]);
pymodule['versionlist'] = (int(setuppy_verinfo_exp[0]), int(setuppy_verinfo_exp[1]), int(setuppy_verinfo_exp[2]), str(setuppy_verinfo_exp[3]), int(setuppy_verinfo_exp[4]));
pymodule['verdate'] = str(setuppy_dateinfo_exp[0])+"."+str(setuppy_dateinfo_exp[1])+"."+str(setuppy_dateinfo_exp[2]);
pymodule['verdaterc'] = int(setuppy_dateinfo_exp[4]);
pymodule['verdatelist'] = (int(setuppy_dateinfo_exp[0]), int(setuppy_dateinfo_exp[1]), int(setuppy_dateinfo_exp[2]), str(setuppy_dateinfo_exp[3]), int(setuppy_dateinfo_exp[4]));
pymodule['name'] = 'PyUPC-EAN';
pymodule['author'] = 'Kazuki Przyborowski';
pymodule['authoremail'] = 'kazuki.przyborowski@gmail.com';
pymodule['maintainer'] = 'Kazuki Przyborowski';
pymodule['maintaineremail'] = 'kazuki.przyborowski@gmail.com';
pymodule['description'] = 'A barcode library/module for python.';
pymodule['license'] = 'Revised BSD License';
pymodule['keywords'] = 'python barcode pyupc-ean pyupcean barcodegenerator barcode-generator barcodelibrary barcode-library barcodes codabar msi code11 code-11 code39 code-39 code93 code-93 code128 code-128 ean ean13 ean-13 ean2 ean-2 ean5 ean-5 ean8 ean-8 itf itf14 itf-14 stf upc upca upc-a upce upc-e gtin2 gtin-2 gtin5 gtin-5 gtin8 gtin-8 gtin12 gtin-12 gtin13 gtin-13 gtin14 gtin-14 ocr-a ocra ocr-b ocrb';
pymodule['url'] = 'https://github.com/GameMaker2k/PyUPC-EAN';
pymodule['downloadurl'] = 'https://github.com/GameMaker2k/PyUPC-EAN/archive/master.tar.gz';
pymodule['packages'] = find_packages();
pymodule['packagedata'] = {'upcean/fonts': ['*.otf', '*.ttf'], 'upcean/xml': ['*.dtd', '*.xsl', '*.xsd', '*.rng', '*.rnc']};
pymodule['includepackagedata'] = True;
pymodule['installrequires'] = install_requires;
pymodule['extrasrequires'] = extras_requires_dict;
pymodule['longdescription'] = 'PyUPC-EAN is a barcode library/module for Python. It supports the barcode formats upc-e, upc-a, ean-13, ean-8, ean-2, ean-5, itf14, codabar, code11, code39, code93, code128, code-128, and msi.';
pymodule['platforms'] = 'OS Independent';
pymodule['zipsafe'] = False;
# pymodule['pymodules'] = [y for x in os.walk("upcean") for y in glob.glob(os.path.join(x[0], '*.py'))];
pymodule['pymodules'] = [];
pymodule['classifiers'] = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Customer Service',
  'Intended Audience :: Developers',
  'Intended Audience :: Other Audience',
  'License :: OSI Approved',
  'License :: OSI Approved :: BSD License',
  'Natural Language :: English',
  'Operating System :: MacOS',
  'Operating System :: MacOS :: MacOS X',
  'Operating System :: Microsoft',
  'Operating System :: Microsoft :: Windows',
  'Operating System :: OS/2',
  'Operating System :: OS Independent',
  'Operating System :: POSIX',
  'Operating System :: Unix',
  'Programming Language :: Python',
  'Topic :: Multimedia :: Graphics',
  'Topic :: Office/Business',
  'Topic :: Office/Business :: Financial',
  'Topic :: Office/Business :: Financial :: Point-Of-Sale',
  'Topic :: Utilities',
  'Topic :: Software Development',
  'Topic :: Software Development :: Libraries',
  'Topic :: Software Development :: Libraries :: Python Modules'
 ];
if(len(sys.argv)>1 and (sys.argv[1]=="versioninfo" or sys.argv[1]=="getversioninfo")):
 import json;
 pymodule_data = json.dumps(pymodule);
 print(pymodule_data);
 sys.exit();
if(len(sys.argv)>1 and (sys.argv[1]=="sourceinfo" or sys.argv[1]=="getsourceinfo")):
 srcinfofilename = os.path.realpath("."+os.path.sep+pkg_resources.to_filename(pymodule['name'])+".egg-info"+os.path.sep+"SOURCES.txt");
 srcinfofile = open(srcinfofilename, "r");
 srcinfodata = srcinfofile.read();
 srcinfofile.close();
 srcinfolist = srcinfodata.split('\n');
 srcfilelist = "";
 srcpdir = os.path.basename(os.path.dirname(os.path.realpath(__file__)));
 for ifile in srcinfolist:
  srcfilelist = "."+os.path.sep+srcpdir+os.path.sep+ifile+" "+srcfilelist;
 print(srcfilelist);
 sys.exit();
if(len(sys.argv)>1 and sys.argv[1]=="cleansourceinfo"):
 os.system("rm -rfv \""+os.path.realpath("."+os.path.sep+"dist\""));
 os.system("rm -rfv \""+os.path.realpath("."+os.path.sep+pkg_resources.to_filename(pymodule['name'])+".egg-info\""));
 sys.exit();

if(pygenbuildinfo):
 mycurtime = datetime.datetime.now();
 mycurtimetuple = mycurtime.timetuple();
 mycurtimestamp = int(time.mktime(mycurtimetuple));
 '''verinfodata = verinfodata.replace('__build_time__ = {"timestamp": None, "year": None, "month": None, "day": None, "hour": None, "minute": None, "second": None};', '__build_time__ = {"timestamp": '+str(mycurtimestamp)+', "year": '+str(mycurtimetuple[0])+', "month": '+str(mycurtimetuple[1])+', "day": '+str(mycurtimetuple[2])+', "hour": '+str(mycurtimetuple[3])+', "minute": '+str(mycurtimetuple[4])+', "second": '+str(mycurtimetuple[5])+'};');'''
 verinfodata = re.sub("__build_time__ \= \{.*\}\;", '__build_time__ = {"timestamp": '+str(mycurtimestamp)+', "year": '+str(mycurtimetuple[0])+', "month": '+str(mycurtimetuple[1])+', "day": '+str(mycurtimetuple[2])+', "hour": '+str(mycurtimetuple[3])+', "minute": '+str(mycurtimetuple[4])+', "second": '+str(mycurtimetuple[5])+'};', verinfodata);
 utccurtime = datetime.datetime.utcnow();
 utccurtimetuple = utccurtime.timetuple();
 utccurtimestamp = int(time.mktime(utccurtimetuple));
 '''verinfodata = verinfodata.replace('__build_time_utc__ = {"timestamp": None, "year": None, "month": None, "day": None, "hour": None, "minute": None, "second": None};', '__build_time_utc__ = {"timestamp": '+str(utccurtimestamp)+', "year": '+str(utccurtimetuple[0])+', "month": '+str(utccurtimetuple[1])+', "day": '+str(utccurtimetuple[2])+', "hour": '+str(utccurtimetuple[3])+', "minute": '+str(utccurtimetuple[4])+', "second": '+str(utccurtimetuple[5])+'};');'''
 verinfodata = re.sub("__build_time_utc__ \= \{.*\}\;", '__build_time_utc__ = {"timestamp": '+str(utccurtimestamp)+', "year": '+str(utccurtimetuple[0])+', "month": '+str(utccurtimetuple[1])+', "day": '+str(utccurtimetuple[2])+', "hour": '+str(utccurtimetuple[3])+', "minute": '+str(utccurtimetuple[4])+', "second": '+str(utccurtimetuple[5])+'};', verinfodata);
 linuxdist = None;
 try:
  linuxdist = platform.linux_distribution();
 except AttributeError:
  linuxdist = None;
 if(sys.version[0]=="2"):
  '''verinfodata = verinfodata.replace('__build_python_info__ = {"python_branch": None, "python_build": None, "python_compiler": None, "python_implementation": None, "python_revision": None, "python_version": None, "python_version_tuple": None, "release": None, "system": None, "uname": None, "machine": None, "node": None, "platform": None, "processor": None, "version": None, "java_ver": None, "win32_ver": None, "mac_ver": None, "linux_distribution": None, "libc_ver": None};', '__build_python_info__ = '+str({'python_branch': platform.python_branch(), 'python_build': platform.python_build(), 'python_compiler': platform.python_compiler(), 'python_implementation': platform.python_implementation(), 'python_revision': platform.python_revision(), 'python_version': platform.python_version(), 'python_version_tuple': platform.python_version_tuple(), 'release': platform.release(), 'system': platform.system(), 'uname': platform.uname(), 'machine': platform.machine(), 'node': platform.node(), 'platform': platform.platform(), 'processor': platform.processor(), 'architecture': platform.architecture(), 'version': platform.version(), 'java_ver': platform.java_ver(), 'win32_ver': platform.win32_ver(), 'mac_ver': platform.mac_ver(), 'linux_distribution': linuxdist, 'libc_ver': platform.libc_ver()})+';');'''
  verinfodata = re.sub("__build_python_info__ \= \{.*\}\;", '__build_python_info__ = '+str({'python_branch': platform.python_branch(), 'python_build': platform.python_build(), 'python_compiler': platform.python_compiler(), 'python_implementation': platform.python_implementation(), 'python_revision': platform.python_revision(), 'python_version': platform.python_version(), 'python_version_tuple': platform.python_version_tuple(), 'release': platform.release(), 'system': platform.system(), 'uname': platform.uname(), 'machine': platform.machine(), 'node': platform.node(), 'platform': platform.platform(), 'processor': platform.processor(), 'architecture': platform.architecture(), 'version': platform.version(), 'java_ver': platform.java_ver(), 'win32_ver': platform.win32_ver(), 'mac_ver': platform.mac_ver(), 'linux_distribution': linuxdist, 'libc_ver': platform.libc_ver()})+';', verinfodata);
 if(sys.version[0]=="3"):
  '''verinfodata = verinfodata.replace('__build_python_info__ = {"python_branch": None, "python_build": None, "python_compiler": None, "python_implementation": None, "python_revision": None, "python_version": None, "python_version_tuple": None, "release": None, "system": None, "uname": None, "machine": None, "node": None, "platform": None, "processor": None, "version": None, "java_ver": None, "win32_ver": None, "mac_ver": None, "linux_distribution": None, "libc_ver": None};', '__build_python_info__ = '+str({'python_branch': platform.python_branch(), 'python_build': platform.python_build(), 'python_compiler': platform.python_compiler(), 'python_implementation': platform.python_implementation(), 'python_revision': platform.python_revision(), 'python_version': platform.python_version(), 'python_version_tuple': platform.python_version_tuple(), 'release': platform.release(), 'system': platform.system(), 'uname': (platform.uname()[0], platform.uname()[1], platform.uname()[2], platform.uname()[3], platform.uname()[4], platform.uname()[5]), 'machine': platform.machine(), 'node': platform.node(), 'platform': platform.platform(), 'processor': platform.processor(), 'architecture': platform.architecture(), 'version': platform.version(), 'java_ver': platform.java_ver(), 'win32_ver': platform.win32_ver(), 'mac_ver': platform.mac_ver(), 'linux_distribution': linuxdist, 'libc_ver': platform.libc_ver()})+';');'''
  verinfodata = re.sub("__build_python_info__ \= \{.*\}\;", '__build_python_info__ = '+str({'python_branch': platform.python_branch(), 'python_build': platform.python_build(), 'python_compiler': platform.python_compiler(), 'python_implementation': platform.python_implementation(), 'python_revision': platform.python_revision(), 'python_version': platform.python_version(), 'python_version_tuple': platform.python_version_tuple(), 'release': platform.release(), 'system': platform.system(), 'uname': (platform.uname()[0], platform.uname()[1], platform.uname()[2], platform.uname()[3], platform.uname()[4], platform.uname()[5]), 'machine': platform.machine(), 'node': platform.node(), 'platform': platform.platform(), 'processor': platform.processor(), 'architecture': platform.architecture(), 'version': platform.version(), 'java_ver': platform.java_ver(), 'win32_ver': platform.win32_ver(), 'mac_ver': platform.mac_ver(), 'linux_distribution': linuxdist, 'libc_ver': platform.libc_ver()})+';', verinfodata);
 '''verinfodata = verinfodata.replace('__build_python_is_set__ = False;', '__build_python_is_set__ = True;');'''
 verinfodata = re.sub("__build_python_is_set__ \= .*\;", '__build_python_is_set__ = True;', verinfodata);
 verinfofile = open(verinfofilename, "w");
 verinfofile.write(verinfodata);
 verinfofile.close();

setup(
 name = pymodule['name'],
 version = pymodule['version'],
 author = pymodule['author'],
 author_email = pymodule['authoremail'],
 maintainer = pymodule['maintainer'],
 maintainer_email = pymodule['maintaineremail'],
 description = pymodule['description'],
 license = pymodule['license'],
 keywords = pymodule['keywords'],
 url = pymodule['url'],
 download_url = pymodule['downloadurl'],
 packages = pymodule['packages'],
 package_data = pymodule['packagedata'],
 include_package_data = pymodule['includepackagedata'],
 install_requires = pymodule['installrequires'],
 extras_require = pymodule['extrasrequires'],
 long_description = pymodule['longdescription'],
 platforms = pymodule['platforms'],
 zip_safe = pymodule['zipsafe'],
 py_modules = pymodule['pymodules'],
 classifiers = pymodule['classifiers']
)



# -*- coding: utf-8 -*-
'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
    Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: support.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
'''

from __future__ import absolute_import, division, print_function, unicode_literals;
import imp, platform;
from upcean.versioninfo import getcuryear, __author__, __copyright__, __credits__, __copyright_year__, __license__, __license_string__, __maintainer__, __email__, __status__, __project__, __project_url__, __version_info__, __build_time__, __build_time_utc__, __build_python_info__, __build_python_is_set__, get_build_python_info, __revision__, __version__, __version_alt__, version_info, __version_date_info__, __version_date__, __version_date_alt__, version_date;

''' // Barcode Support List '''
bctype_dict={'EAN2': "ean2", 'UPCS2': "ean2", 'EAN5': "ean5", 'UPCS5': "ean5", 'UPCA': "upca", 'UPCE': "upce", 'EAN13': "ean13",'EAN8': "ean8",'STF': "stf", 'ITF': "itf", 'ITF6': "itf6", 'ITF14': "itf14", 'CODE11': "code11", 'CODE39': "code39", 'CODE93': "code93", 'CODE128': "code128", 'CODE128Alt': "code128alt", 'CODE128Dec': "code128dec", 'CODABAR': "codabar", 'MSI': "msi", "GOODWILL": "goodwill"};
bctype_dict_alt={'ean2': "EAN2", 'ean5': "EAN5", 'upca': "UPCA", 'upce': "UPCE", 'ean13': "EAN13",'ean8': "EAN8",'stf': "STF", 'itf': "ITF", 'itf6': "ITF6", 'itf14': "ITF14", 'code11': "CODE11", 'code39': "CODE39", 'code93': "CODE93", 'code128': "CODE128", 'code128alt': "CODE128Alt", 'code128dec': "CODE128Dec", 'codabar': "CODABAR", 'msi': "MSI", "goodwill": "GOODWILL"};
bctype_list=["ean2", "ean2", "ean5", "ean5", "upca", "upce", "ean13", "ean8", "stf", "itf", "itf6", "itf14", "code11", "code39", "code93", "code128", "code128alt", "code128dec", "codabar", "msi"];
PROVIDED_BARCODES=bctype_list;
bctype_tuple=("ean2", "ean2", "ean5", "ean5", "upca", "upce", "ean13", "ean8", "stf", "itf", "itf6", "itf14", "code11", "code39", "code93", "code128", "code128alt", "code128dect", "codabar", "msi");
bctype_name={'ean2': "EAN-2", 'ean5': "EAN-5", 'upca': "UPC-A", 'upce': "UPC-E", 'ean13': "EAN-13", 'ean8': "EAN-8", 'stf': "STF", 'itf': "ITF", 'itf6': "ITF-6", 'itf14': "ITF-14", "code11": "Code 11", "code39": "Code 39", "code93": "Code 93", "code128": "Code 128", "code128alt": "Code 128 Alt", "code128dec": "Code 128 Dec", 'codabar': "Codabar", 'msi': "MSI", "goodwill": "GOODWILL"};
def supported_barcodes(return_type="dict"):
 if(return_type=="dict"):
  return {'EAN2': "ean2", 'UPCS2': "ean2", 'EAN5': "ean5", 'UPCS5': "ean5", 'UPCA': "upca", 'UPCE': "upce", 'EAN13': "ean13",'EAN8': "ean8",'STF': "stf", 'ITF': "itf", 'ITF6': "itf6", 'ITF14': "itf14", 'CODE11': "code11", 'CODE39': "code39", 'CODE93': "code93", 'CODE128': "code128", 'CODE128Alt': "code128alt", 'CODE128Dec': "code128dec", 'CODABAR': "codabar", 'MSI': "msi", "GOODWILL": "goodwill"};
 if(return_type=="list"):
  return ["ean2", "ean2", "ean5", "ean5", "upca", "upce", "ean13", "ean8", "stf", "itf", "itf6", "itf14", "code11", "code39", "code93", "code128", "code128alt", "code128dec", "codabar", "msi", "goodwill"];
 if(return_type=="tuple"):
  return ("ean2", "ean2", "ean5", "ean5", "upca", "upce", "ean13", "ean8", "stf", "itf", "itf6", "itf14", "code11", "code39", "code93", "code128", "code128alt", "code128dec", "codabar", "msi", "goodwill");
 return False;
def barcode_support(return_type="dict"):
 return supported_barcodes(return_type);
def get_barcode_name(barcode_type="upca"):
 bctype_name={'ean2': "EAN-2", 'ean5': "EAN-5", 'upca': "UPC-A", 'upce': "UPC-E", 'ean13': "EAN-13", 'ean8': "EAN-8", 'stf': "STF", 'itf': "ITF", 'itf6': "ITF-6", 'itf14': "ITF-14", "code11": "Code 11", "code39": "Code 39", "code93": "Code 93", "code128": "Code 128", "code128alt": "Code 128 Alt", "code128dec": "Code 128 dec", 'codabar': "Codabar", 'msi': "MSI", "goodwill": "GOODWILL"};
 return bctype_name.get(barcode_type, False);

def check_for_cairo():
 # PIL Support Check
 cairosupport = True;
 try:
  imp.find_module('cairo');
  cairosupport = True;
 except ImportError:
  cairosupport = False
 return cairosupport;

def check_for_pil():
 # PIL Support Check
 pilsupport = True;
 try:
  imp.find_module('PIL');
  pilsupport = True;
 except ImportError:
  try:
   imp.find_module('Image');
   pilsupport = True;
  except ImportError:
   try:
    from PIL import Image, ImageDraw, ImageFont;
    pilsupport = True;
   except ImportError:
    pilsupport = False;
   return pilsupport;
 return pilsupport;

def check_for_pillow():
 pilsupport = check_for_pil();
 if(not pilsupport):
  return pilsupport;
 if(pilsupport):
  from PIL import Image;
  try:
   pil_ver = Image.PILLOW_VERSION;
   pil_is_pillow = True;
  except AttributeError:
   try:
    pil_ver = Image.__version__;
    pil_is_pillow = True;
   except AttributeError:
    pil_is_pillow = False;
   except NameError:
    pil_is_pillow = False;
  except NameError:
   try:
    pil_ver = Image.__version__;
    pil_is_pillow = True;
   except AttributeError:
    pil_is_pillow = False;
   except NameError:
    pil_is_pillow = False;
 return pil_is_pillow;

def check_pil_is_pillow():
 pilsupport = False;
 if(check_for_pil()):
  pilsupport = True;
 pil_is_pillow = False;
 if(pilsupport is True and check_for_pillow() is True):
  pil_is_pillow = True;
 if(pilsupport is False or (pilsupport is True and check_for_pillow() is False)):
  pil_is_pillow = False;
 return pil_is_pillow;

def check_if_pil_is_pillow():
 pil_is_pillow = check_pil_is_pillow();
 return pil_is_pillow;

def check_for_pil_only():
 pilsupport = False;
 if(check_for_pil()):
  pilsupport = True;
 pil_is_not_pillow = False;
 if((pilsupport is True and check_for_pillow() is True) or pilsupport is False):
  pil_is_not_pillow = False;
 if(pilsupport is True and check_for_pillow() is False):
  pil_is_not_pillow = True;
 return pil_is_pillow;

def check_only_for_pil():
 pil_is_not_pillow = check_pil_is_pillow();
 return pil_is_not_pillow;

def check_pil_is_not_pillow():
 pil_is_not_pillow = check_pil_is_pillow();
 return pil_is_not_pillow;

def check_if_pil_is_not_pillow():
 pil_is_not_pillow = check_pil_is_pillow();
 return pil_is_not_pillow;

def get_pil_version(infotype=None):
 pilsupport = check_for_pil();
 if(not pilsupport):
  return pilsupport;
 if(pilsupport):
  from PIL import Image;
  try:
   pillow_ver = Image.PILLOW_VERSION;
   pillow_ver = pillow_ver.split(".");
   pillow_ver = [int(x) for x in pillow_ver];
   pil_is_pillow = True;
  except AttributeError:
   pillow_ver = None;
   pil_is_pillow = False;
  except NameError:
   pillow_ver = None;
   pil_is_pillow = False;
  try:
   pil_ver = Image.VERSION;
   pil_ver = pil_ver.split(".");
   pil_ver = [int(x) for x in pil_ver];
  except AttributeError:
   pil_ver = None;
  except NameError:
   pil_ver = None;
  if(pillow_ver is None and pil_ver is not None):
   pil_info = {'pil_ver': pil_ver, 'pil_is_pillow': pil_is_pillow};
   return pil_info.get(infotype, pil_info);
  if(pillow_ver is not None and pil_ver is not None):
   pil_info = {'pil_ver': pil_ver, 'pillow_ver': pillow_ver, 'pil_is_pillow': pil_is_pillow};
   return pil_info.get(infotype, pil_info);
  if(pillow_ver is not None and pil_ver is None):
   pil_info = {'pillow_ver': pillow_ver, 'pil_is_pillow': pil_is_pillow};
   return pil_info.get(infotype, pil_info);

def get_pillow_version(infotype=None):
 pilsupport = check_for_pil();
 if(not pilsupport):
  return pilsupport;
 if(pilsupport):
  from PIL import Image;
  try:
   pillow_ver = Image.PILLOW_VERSION;
   pillow_ver = pillow_ver.split(".");
   pillow_ver = [int(x) for x in pillow_ver];
   pil_is_pillow = True;
  except AttributeError:
   try:
    pillow_ver = Image.__version__;
    pil_is_pillow = True;
   except AttributeError:
    pillow_ver = None;
    pil_is_pillow = False;
   except NameError:
    pillow_ver = None;
    pil_is_pillow = False;
  except NameError:
   try:
    pillow_ver = Image.__version__;
    pil_is_pillow = True;
   except AttributeError:
    pillow_ver = None;
    pil_is_pillow = False;
   except NameError:
    pillow_ver = None;
    pil_is_pillow = False;
  if(pillow_ver is None):
   return False;
  if(pillow_ver is not None):
   pillow_info = {'pillow_ver': pillow_ver, 'pil_is_pillow': pil_is_pillow};
   return pillow_info.get(infotype, pillow_info);

linuxdist = None;
try:
 linuxdist = platform.linux_distribution();
except AttributeError:
 linuxdist = None;

python_info = {'python_branch': platform.python_branch(), 'python_build': platform.python_build(), 'python_compiler': platform.python_compiler(), 'python_implementation': platform.python_implementation(), 'python_revision': platform.python_revision(), 'python_version': platform.python_version(), 'python_version_tuple': platform.python_version_tuple(), 'release': platform.release(), 'system': platform.system(), 'uname': platform.uname(), 'architecture': platform.architecture(), 'machine': platform.machine(), 'node': platform.node(), 'platform': platform.platform(), 'processor': platform.processor(), 'version': platform.version(), 'java_ver': platform.java_ver(), 'win32_ver': platform.win32_ver(), 'mac_ver': platform.mac_ver(), 'linux_distribution': linuxdist, 'libc_ver': platform.libc_ver()};
if(not __build_python_is_set__):
 __build_python_info__ = python_info;
def get_python_info(infotype=None):
 global python_info;
 python_info = python_info;
 if(infotype is None):
  return python_info;
 if(infotype is not None):
  return python_info.get(infotype, python_info);

pilsupport = check_for_pil();
cairosupport = check_for_cairo();
